@@ -79,6 +79,9 @@
 /* If you don't have gcc, define this */
 #undef OLD_TOOLS 
 
+/* Found some version of curses that we're going to use */
+#undef HAS_CURSES
+
 /* Are you using other type of curses? */
 #undef OTHER_CURSES
 
@@ -86,7 +89,7 @@
 #undef SUBSHELL_OPTIONAL
 
 /* Use SunOS SysV curses? */
-#undef SUNOS_CURSES
+#undef USE_SUNOS_CURSES
 
 /* Use old BSD curses? */
 #undef USE_BSD_CURSES
@@ -98,7 +101,7 @@
 #undef USE_NCURSES
 
 /* If you Curses does not have color define this one */
-#undef NO_COLOR_SUPPORT
+#undef NO_COLOR_CURSES
 
 /* Support the Midnight Commander Virtual File System? */
 #undef USE_VFS
@@ -126,17 +129,6 @@
  */
 #undef NEED_EXTRA_DIRENT_BUFFER
 
-/* Define if you want the du -s summary */
-#undef HAVE_DUSUM
-
-/* Define if your du does handle -b correctly */
-#undef DUSUM_USEB
-
-/* Define to size of chunks du is displaying its information.
- * If DUSUM_USEB is defined, this should be 1
- */
-#define DUSUM_FACTOR 512
-
 /* Define this one if you want termnet support */
 #undef USE_TERMNET
 
