@@ -176,7 +176,7 @@ layout_panel_gone (WPanel *panel)
 void
 set_hintbar (char *str)
 {
-	gtk_label_set (GTK_LABEL (current_panel_ptr->panel->status), str);
+  /*gtk_label_set (GTK_LABEL (current_panel_ptr->panel->status), str);*/
 	x_flush_events ();
 }
 
@@ -265,96 +265,101 @@ void configure_box (void);
 GtkCheckMenuItem *gnome_toggle_snap (void);
 
 GnomeUIInfo gnome_panel_file_menu [] = {
-	{ GNOME_APP_UI_ITEM, N_("New window"),        N_("Opens a new window"), gnome_open_panel },
-	{ GNOME_APP_UI_ITEM, N_("New Terminal"),     N_("Opens a terminal"), gnome_open_terminal },
-	{ GNOME_APP_UI_SEPARATOR },	
-	{ GNOME_APP_UI_ITEM, N_("Copy..."),           N_("Copy files"),       copy_cmd },
-	{ GNOME_APP_UI_ITEM, N_("Rename/Move..."),    N_("Rename or move files"), ren_cmd },
-	{ GNOME_APP_UI_ITEM, N_("New directory..."),  N_("Creates a new folder"), mkdir_cmd },
-	{ GNOME_APP_UI_ITEM, N_("Delete..."),         N_("Delete files from disk"), delete_cmd },
-	{ GNOME_APP_UI_SEPARATOR },	
-	{ GNOME_APP_UI_ITEM, N_("View"),              N_("View file"), panel_action_view },
-	{ GNOME_APP_UI_ITEM, N_("View raw"),          N_("View the file without further processing"),panel_action_view_unfiltered},
-	{ GNOME_APP_UI_SEPARATOR },	
-	{ GNOME_APP_UI_ITEM, N_("Select group by pattern..."),   N_("Select a group of files"), select_cmd },
-	{ GNOME_APP_UI_ITEM, N_("Unselect group by pattern..."), N_("Un-selects a group of marked files"), unselect_cmd },
-	{ GNOME_APP_UI_ITEM, N_("Reverse selection"), N_("Reverses the list of tagged files"), reverse_selection_cmd },
+	{ GNOME_APP_UI_ITEM, N_("_New window"),        N_("Opens a new window"), gnome_open_panel },
+	/* We want to make a new menu entry here... */
+	/* For example: */
+	/* New-> */
+	/*  Command Prompt */
+	/*  Gimp Image */
+	/*  Gnumeric Spreadsheet */
+	/*  Text Document */
+	/*  etc... */
 	{ GNOME_APP_UI_SEPARATOR },
-	{ GNOME_APP_UI_ITEM, N_("Close"),             N_("Close this panel"), gnome_close_panel },
-	{ GNOME_APP_UI_ITEM, N_("Exit"),              N_("Exit program"), gnome_quit_cmd, NULL, NULL,
-	  GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_EXIT },
+	{ GNOME_APP_UI_ITEM, N_("_Open"),              N_("Open selected files"), NULL, NULL,
+	  NULL, GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_OPEN },
+	{ GNOME_APP_UI_ITEM, N_("_Copy..."),           N_("Copy files"), copy_cmd, NULL},
+	{ GNOME_APP_UI_ITEM, N_("_Move..."),           N_("Rename or move files"), ren_cmd },
+	{ GNOME_APP_UI_ITEM, N_("_Delete..."),         N_("Delete files from disk"), delete_cmd },
+	{ GNOME_APP_UI_SEPARATOR },
+	{ GNOME_APP_UI_ITEM, N_("C_lose"),             N_("Close this panel"), gnome_close_panel, NULL,
+	  NULL, GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_CLOSE },
 	{ GNOME_APP_UI_ENDOFINFO, 0, 0 }
 };
 
-GnomeUIInfo gnome_panel_panel_menu [] = {
-	{ GNOME_APP_UI_ITEM, N_("Display mode..."),   N_("Set the display mode for the panel"),  gnome_listing_cmd },
-	{ GNOME_APP_UI_ITEM, N_("Sort order..."),     N_("Changes the sort order of the files"), sort_cmd },
-	{ GNOME_APP_UI_ITEM, N_("Filter..."),         N_("Set a filter for the files"), filter_cmd },
-	{ GNOME_APP_UI_ITEM, N_("Rescan"),            N_("Rescan the directory contents"), reread_cmd },
+GnomeUIInfo gnome_panel_edit_menu [] = {
+	{ GNOME_APP_UI_ITEM, N_("_Cut"),               N_("Cuts the selected files into the cut buffer."),  NULL, NULL,
+	  NULL, GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_CUT },
+	{ GNOME_APP_UI_ITEM, N_("C_opy"),              N_("Copies the selected files into the cut buffer."),  NULL, NULL,
+	  NULL, GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_COPY },
+	{ GNOME_APP_UI_ITEM, N_("_Paste"),             N_("Pastes files from the cut buffer into the current directory"),  NULL, NULL,
+	  NULL, GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_PASTE },
 	{ GNOME_APP_UI_SEPARATOR },
-#ifdef USE_NETCODE
-	{ GNOME_APP_UI_ITEM, N_("Network link..."),   N_("Connect to a remote machine"), netlink_cmd },
-	{ GNOME_APP_UI_ITEM, N_("FTP link..."),       N_("Connect to a remote machine with FTP"), ftplink_cmd },
-#endif
+	{ GNOME_APP_UI_ITEM, N_("_Select Files..."),   N_("Select a group of files"), select_cmd },
+	{ GNOME_APP_UI_ITEM, N_("_Invert Selection"),  N_("Reverses the list of tagged files"), reverse_selection_cmd },
+	{ GNOME_APP_UI_ITEM, N_("_Rescan Directory"),  N_("Rescan the directory contents"), reread_cmd },
+	{ GNOME_APP_UI_SEPARATOR },
+	{ GNOME_APP_UI_ITEM, N_("Preferences..."),     N_("Configure the GNOME Midnight Commander"), configure_box, NULL,
+	  NULL, GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_PROP},
 	{ GNOME_APP_UI_ENDOFINFO, 0, 0 }
 };
 
-GnomeUIInfo gnome_panel_options_menu [] = {
-	{ GNOME_APP_UI_ITEM, N_("Confirmation..."),   N_("Confirmation settings"), confirm_box },
-	{ GNOME_APP_UI_ITEM, N_("Options..."),        N_("Global option settings"), configure_box, NULL, NULL,
-	  GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_PROP },
-#ifdef USE_VFS
-	{ GNOME_APP_UI_ITEM, N_("Virtual FS..."),     N_("Virtual File System settings"), configure_vfs },
-#endif
+GnomeUIInfo gnome_panel_view_menu [] = {
+	{ GNOME_APP_UI_ITEM, N_("Icon View"), NULL, gnome_icon_view_cmd, NULL},
+	{ GNOME_APP_UI_ITEM, N_("Partial View"), NULL, gnome_partial_view_cmd, NULL},
+	{ GNOME_APP_UI_ITEM, N_("Full View"), NULL, gnome_full_view_cmd, NULL},
+	{ GNOME_APP_UI_ITEM, N_("Custom View"), NULL, gnome_custom_view_cmd, NULL},
+	{GNOME_APP_UI_ENDOFINFO, NULL, NULL, NULL, NULL, NULL,
+	 GNOME_APP_PIXMAP_NONE, NULL, 0, 0, NULL}
+};
+
+GnomeUIInfo gnome_panel_layout_menu [] = {
+	{ GNOME_APP_UI_ITEM, N_("_Sort By..."),     N_("Confirmation settings"), gnome_sort_cmd },
+	{ GNOME_APP_UI_ITEM, N_("_Filter View..."),    N_("Global option settings"), filter_cmd },
 	{ GNOME_APP_UI_SEPARATOR },
-	{ GNOME_APP_UI_ITEM, N_("Save setup"),        NULL, save_setup_cmd },
+	{ GNOME_APP_UI_RADIOITEMS, NULL , NULL, gnome_panel_view_menu},
 	{ GNOME_APP_UI_ENDOFINFO, 0, 0 }
 };
 
 GnomeUIInfo gnome_panel_commands_menu [] = {
-	{ GNOME_APP_UI_ITEM, N_("Find..."),           N_("Locate files on disk"),   find_cmd },
-	{ GNOME_APP_UI_ITEM, N_("Hotlist..."),        N_("List of favorite sites"), quick_chdir_cmd },
-	{ GNOME_APP_UI_ITEM, N_("Compare panels..."), N_("Compare panel contents"), gnome_compare_panels },
-	{ GNOME_APP_UI_ITEM, N_("External panelize..."), NULL, external_panelize },
+	{ GNOME_APP_UI_ITEM, N_("_Find File..."),      N_("Locate files on disk"),   find_cmd, NULL,
+	  NULL, GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_JUMP_TO},
+	  
+	{ GNOME_APP_UI_ITEM, N_("_Compare panels..."), N_("Compare two panel contents"), gnome_compare_panels },
+	{ GNOME_APP_UI_ITEM, N_("_Run Command..."),    N_("Run a command and put the results in a panel"), external_panelize },
 #ifdef USE_VFS					  
-	{ GNOME_APP_UI_ITEM, N_("Active VFS list..."),   N_("List of active virtual file systems"), reselect_vfs },
-#endif						  
+	{ GNOME_APP_UI_ITEM, N_("_Active VFS list..."),N_("List of active virtual file systems"), reselect_vfs },
+#endif
 #ifdef USE_EXT2FSLIB
-	{ GNOME_APP_UI_ITEM, N_("Undelete files (ext2fs only)..."), N_("Recover deleted files"), undelete_cmd },
+	/*does this do anything?*/
+/*	{ GNOME_APP_UI_ITEM, N_("_Undelete files (ext2fs only)..."), N_("Recover deleted files"), undelete_cmd },*/
 #endif
 #ifdef WITH_BACKGROUND
-	{ GNOME_APP_UI_ITEM, N_("Background jobs..."),   N_("List of background operations"), jobs_cmd },
+	{ GNOME_APP_UI_ITEM, N_("_Background jobs..."),   N_("List of background operations"), jobs_cmd },
 #endif
 	{ GNOME_APP_UI_ENDOFINFO, 0, 0 }
 };
 
-GnomeUIInfo gnome_panel_desktop_menu [] = {
-	{ GNOME_APP_UI_ITEM, N_("Arrange icons"),     N_("Arranges the icons on the desktop"), gnome_arrange_icons },
-/*	{ GNOME_APP_UI_TOGGLEITEM, N_("Desktop grid"), N_("Use a grid for laying out icons"), gnome_toggle_snap }, */
-	{ GNOME_APP_UI_ENDOFINFO, 0, 0 }
-};
 
 GnomeUIInfo gnome_panel_about_menu [] = {
-	{ GNOME_APP_UI_ITEM, N_("About"),              N_("Information on this program"), gnome_about_cmd, NULL, NULL,
+/*	GNOMEUIINFO_HELP ("midnight-commander"), */
+	{ GNOME_APP_UI_ITEM, N_("_About"),              N_("Information on this program"), gnome_about_cmd, NULL, NULL,
 	  GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_ABOUT },
-	GNOMEUIINFO_HELP ("midnight-commander"),
 	GNOMEUIINFO_END
 };
 
 GnomeUIInfo gnome_panel_menu [] = {
 	{ GNOME_APP_UI_SUBTREE, N_("_File"),     NULL, &gnome_panel_file_menu },
-	{ GNOME_APP_UI_SUBTREE, N_("Window"),    NULL, &gnome_panel_panel_menu },
-	{ GNOME_APP_UI_SUBTREE, N_("Commands"), NULL, &gnome_panel_commands_menu },
-	{ GNOME_APP_UI_SUBTREE, N_("Options"),  NULL, &gnome_panel_options_menu },
-	{ GNOME_APP_UI_SUBTREE, N_("Desktop"),  NULL, &gnome_panel_desktop_menu },
-	{ GNOME_APP_UI_SUBTREE, N_("Help"),     NULL, &gnome_panel_about_menu },
+	{ GNOME_APP_UI_SUBTREE, N_("_Edit"),     NULL, &gnome_panel_edit_menu },
+	{ GNOME_APP_UI_SUBTREE, N_("_Layout"),   NULL, &gnome_panel_layout_menu },
+	{ GNOME_APP_UI_SUBTREE, N_("_Commands"), NULL, &gnome_panel_commands_menu },
+	{ GNOME_APP_UI_SUBTREE, N_("_Help"),     NULL, &gnome_panel_about_menu },
 	{ GNOME_APP_UI_ENDOFINFO, 0, 0 }
 };
 
 GtkCheckMenuItem *
 gnome_toggle_snap (void)
 {
-	return GTK_CHECK_MENU_ITEM (gnome_panel_desktop_menu [1].widget);
+	return NULL; /*GTK_CHECK_MENU_ITEM (gnome_panel_desktop_menu [1].widget);*/
 }
 
 void
@@ -442,7 +447,7 @@ create_container (Dlg_head *h, char *name, char *geometry)
 	if (width != -1 && height != -1)
 		gtk_widget_set_usize (GTK_WIDGET (app), width, height);
 	else
-		gtk_widget_set_usize (GTK_WIDGET (app), 500, 360);
+		gtk_widget_set_usize (GTK_WIDGET (app), 540, 360);
 	if (xpos != -1 && ypos != -1)
 		gtk_widget_set_uposition (GTK_WIDGET (app), xpos, ypos);
 
@@ -472,11 +477,8 @@ create_container (Dlg_head *h, char *name, char *geometry)
 	 */
 	panel->widget.wdata = (widget_data) vbox;
 	container->panel = panel;
-	if (!containers){
-		containers = g_list_alloc ();
-		containers->data = container;
-	} else  
-		containers = g_list_append (containers, container);
+	
+	containers = g_list_append (containers, container);
 
 	if (!current_panel_ptr){
 		current_panel_ptr = container;
