@@ -11,7 +11,7 @@
 #include <stdarg.h>
 #include <string.h>
 #include <ctype.h>
-#define WANT_WIDGETS
+#define WANT_WIDGETS		/* bleah */
 #include "tty.h"		/* for KEY_BACKSPACE */
 #include "x.h"
 #include "main.h"
@@ -26,7 +26,7 @@
 
 GdkColorContext *mc_cc;
 
-#define MAX_COLOR_PAIRS 32
+#define MAX_COLOR_PAIRS 40
 struct gmc_color_pairs_s gmc_color_pairs [MAX_COLOR_PAIRS];
 
 char *default_edition_colors =
@@ -38,6 +38,7 @@ char *default_edition_colors =
 "marked=yellow,seagreen:"
 "execute=slateblue:"
 "link=green:"
+"stalledlink=brightred:"
 "device=magenta:"
 "core=red:"
 "menuhotsel=cyan,black:"
@@ -45,6 +46,8 @@ char *default_edition_colors =
 "reverse=black,lightcyan:"
 "special=black";
 
+int dialog_panel_callback (struct Dlg_head *h, int id, int msg);
+
 /* The Dlg_head for the whole desktop */
 Dlg_head *desktop_dlg;
 
@@ -90,27 +93,62 @@ gmc_color_init (void)
 int
 xtoolkit_init (int *argc, char *argv [])
 {
-	LINES = 40;
-	COLS = 80;
-	
-/*	gnome_init ("gmc", NULL, *argc, argv, 0, NULL); */
 	gmc_color_init ();
-	/* FIXME: Maybe this should return something from gnome_init() */
+
 	return 0;
 }
 
-int
-xtoolkit_end (void)
+void
+interactive_display (char *filename, char *node)
 {
-	return 1;
+	/* FIXME: Implement gnome version */
 }
 
+void
+beep (void)
+{
+	gdk_beep ();
+}
+
+void
+xtoolkit_end (void)
+{
+	/* Do nothing */
+}
+
+/*
+ * Keystroke event handler for all of the Gtk widgets created by
+ * the GNOME Midnight Commander.  A special case is handled at
+ * the top
+ */
 int
 dialog_key_pressed (GtkWidget *win, GdkEventKey *event, Dlg_head *h)
 {
+	GtkWidget *w;
 	static int on_escape;
 	int key;
 
+	/*
+	 * Find out if the focused widget is an IconList and
+	 * if so, check if it has a currently focused item is
+	 * on editing mode as we do not want to handle key
+	 * events while the icon name is being edited.
+	 */
+	w = win;
+	while (w && (GTK_IS_CONTAINER (w) && !GNOME_IS_ICON_LIST (w)))
+		w = GTK_CONTAINER (w)->focus_child;
+	
+	if (w && GNOME_IS_ICON_LIST (w)){
+		GnomeCanvas *c = GNOME_CANVAS (w);
+
+		if (c->focused_item && GNOME_IS_ICON_TEXT_ITEM (c->focused_item)){
+			GnomeIconTextItem *i = GNOME_ICON_TEXT_ITEM (c->focused_item);
+
+			if (i->editing)
+				return FALSE;
+		}
+	} 
+
 	key = translate_gdk_keysym_to_curses (event);
 	if (key == -1)
 		return FALSE;
@@ -136,10 +174,10 @@ dialog_key_pressed (GtkWidget *win, GdkEventKey *event, Dlg_head *h)
 		on_escape = 0;
 	}
 	
-	gtk_signal_emit_stop_by_name (GTK_OBJECT (win), "key_press_event");
-	if (dlg_key_event (h, key))
+	if (dlg_key_event (h, key)){
+		gtk_signal_emit_stop_by_name (GTK_OBJECT (win), "key_press_event");
 		return TRUE;
-	else
+	} else
 		return FALSE;
 }
 
@@ -160,8 +198,10 @@ xtoolkit_create_dialog (Dlg_head *h, int flags)
 	if (!(flags & DLG_NO_TOPLEVEL)){
 		if (flags & DLG_GNOME_APP)
 			win = gnome_app_new ("mc", h->name);
-		else 
+		else {
 			win = gtk_window_new (GTK_WINDOW_TOPLEVEL);
+			gtk_window_set_position (GTK_WINDOW (win), GTK_WIN_POS_MOUSE);
+		}
 	} else
 		win = 0;
 	
@@ -174,8 +214,9 @@ xtoolkit_create_dialog (Dlg_head *h, int flags)
 		
 		bind_gtk_keys (GTK_WIDGET (ted), h);
 	}
-	if (win)
+	if (win){
 		bind_gtk_keys (GTK_WIDGET (win), h);
+	}
 	return (widget_data) win;
 }
 
@@ -400,11 +441,10 @@ dialog_panel_callback (struct Dlg_head *h, int id, int msg)
 	if (msg == DLG_UNHANDLED_KEY || msg == DLG_HOTKEY_HANDLED)
 		return midnight_callback (h, id, msg);
 
-	return default_dlg_callback (h, id, msg);
+	return 0;
 }
 
-extern GList *directory_list;
-extern GList *geometry_list;
+extern char *cmdline_geometry;
 
 typedef struct {
 	char *dir; char *geometry;
@@ -466,7 +506,11 @@ create_panels (void)
 	char  *geo;
 	WPanel *panel;
 
+#if 1
+	desktop_init ();
+#else
 	start_desktop ();
+#endif
 	cmdline = command_new (0, 0, 0);
 	the_hint = label_new (0, 0, 0, NULL);
 
@@ -474,33 +518,35 @@ create_panels (void)
 	
 	desktop_dlg = create_dlg (0, 0, 24, 80, 0, dialog_panel_callback, "[panel]", "midnight", DLG_NO_TED);
 
+#if 0
 	if (directory_list){
-		g   = geometry_list;
+
 		for (p = directory_list; p; p = p->next){
-			if (g){
-				geo = g->data;
-				g = g->next;
-			} else
-				geo = NULL;
-			create_one_panel (p->data, geo);
+			create_one_panel (p->data, cmdline_geometry);
 		}
 		panel = NULL;
-	} else {
-		char *geometry = geometry_list ? geometry_list->data : NULL;
-		panel = create_one_panel (".", geometry);
+	} else
+#endif
+	  {
+		panel = create_one_panel (".", cmdline_geometry);
 
 		if (nowindows){
 			gtk_idle_add (idle_destroy_window, panel);
 			panel->widget.options |= W_PANEL_HIDDEN;
 		}
 	}
+#if 0
 	g_list_free (directory_list);
-	g_list_free (geometry_list);
+#endif
 
 	run_dlg (desktop_dlg);
 
 	/* shutdown gnome specific bits of midnight commander */
+#if 1
+	desktop_destroy ();
+#else
 	stop_desktop ();
+#endif
 }
 
 static void
@@ -532,15 +578,14 @@ session_save_state (GnomeClient *client, gint phase, GnomeRestartStyle save_styl
 	for (i = 1, l = containers; l; l = l->next){
 		PanelContainer *pc = l->data;
 		int x, y, w, h;
-		char *buffer = g_malloc (32);
+		char *geom;
 
-		gdk_window_get_origin (GTK_WIDGET (pc->panel->widget.wdata)->window, &x, &y);
-		gdk_window_get_size   (GTK_WIDGET (pc->panel->widget.wdata)->window, &w, &h);
-		sprintf (buffer, "%dx%d+%d+%d", w, h, x, y);
+		geom = gnome_geometry_string (GTK_WIDGET (pc->panel->widget.wdata)->window);
+		
 		argv [i++] = pc->panel->cwd;
 		argv [i++] = "--geometry";
-		argv [i++] = buffer;
-		free_list = g_list_append (free_list, buffer);
+		argv [i++] = geom;
+		free_list = g_list_append (free_list, geom);
 	}
 
 	/* If no windows were open */
