@@ -51,10 +51,12 @@
 #endif
 #include "util.h"
 #include "dialog.h"
-#include "file.h"
 #include "background.h"
 #include "mad.h"
 #include "key.h"	/* For add_select_channel(), delete_select_channel() */
+#include "regex.h"
+#include "file.h"
+#include "filegui.h"
 
 /* If true, this is a background process */
 int we_are_background = 0;
@@ -173,7 +175,7 @@ do_background (char *info)
     }
 }
 
-char *
+static char *
 background_title (char *str)
 {
     char *result = copy_strings (_("Background process:"), str, NULL);
@@ -182,7 +184,7 @@ background_title (char *str)
 }
 
 /* {{{ Routines that do the real job */
-void
+static void
 real_message_1s (enum OperationMode mode, int *flags, char *title, char *str1)
 {
     char *full_title;
@@ -198,7 +200,7 @@ real_message_1s (enum OperationMode mode, int *flags, char *title, char *str1)
 	free (full_title);
 }
 
-void
+static void
 real_message_2s (enum OperationMode mode, int *flags, char *title, char *str1, char *str2)
 {
     char *full_title;
@@ -214,7 +216,7 @@ real_message_2s (enum OperationMode mode, int *flags, char *title, char *str1, c
 	free (full_title);
 }
 
-void
+static void
 real_message_3s (enum OperationMode mode, int *flags, char *title, char *str1, char *str2, const char *str3)
 {
     char *full_title;
@@ -340,9 +342,9 @@ background_attention (int fd, void *xpid)
 	}
 	
 	/* Send the result code and the value for shared variables */
-	write (fd, &result,           sizeof (int));
-	write (fd, &do_append,        sizeof (do_append));
-	write (fd, &recursive_result, sizeof (recursive_result));
+	write (fd, &result,                  sizeof (int));
+	write (fd, &file_progress_do_append, sizeof (file_progress_do_append));
+	write (fd, &file_progress_recursive_result, sizeof (file_progress_recursive_result));
 	
     } else if (type == Return_String) {
 	int len;
@@ -394,7 +396,7 @@ background_attention (int fd, void *xpid)
 /* }}} */
 
 /* {{{ client RPC routines */
-void
+static void
 parent_call_header (void *routine, int argc, enum ReturnType type)
 {
     write (parent_fd, &routine, sizeof (routine));
@@ -423,12 +425,12 @@ parent_call (void *routine, int argc, ...)
      * variables that may be modified in the parent that affect our behaviour
      */
     read (parent_fd, &i,         sizeof (int));
-    read (parent_fd, &do_append, sizeof (do_append));
-    read (parent_fd, &recursive_result, sizeof (recursive_result));
+    read (parent_fd, &file_progress_do_append, sizeof (file_progress_do_append));
+    read (parent_fd, &file_progress_recursive_result, sizeof (file_progress_recursive_result));
     return i;
 }
 
-char *
+static char *
 parent_call_string (void *routine, int argc, ...)
 {
     va_list ap;
