@@ -98,7 +98,8 @@ static struct {
 };
 
 #ifndef HAVE_X
-static void chown_refresh (void)
+static void
+chown_refresh (void)
 {
     attrset (COLOR_NORMAL);
     dlg_erase (ch_dlg);
@@ -132,7 +133,8 @@ static void chown_refresh (void)
 }
 #endif
 
-static char *next_file (void)
+static char *
+next_file (void)
 {
     while (!cpanel->dir.list[current_file].f.marked)
 	current_file++;
@@ -140,7 +142,8 @@ static char *next_file (void)
     return cpanel->dir.list[current_file].fname;
 }
 
-static int chown_callback (Dlg_head * h, int Par, int Msg)
+static int
+chown_callback (Dlg_head * h, int Par, int Msg)
 {
     switch (Msg) {
 #ifndef HAVE_X
@@ -152,12 +155,14 @@ static int chown_callback (Dlg_head * h, int Par, int Msg)
     return 0;
 }
 
-static int l_call (void *data)
+static int
+l_call (void *data)
 {
     return 1;
 }
 
-static void init_chown (void)
+static void
+init_chown (void)
 {
     int i;
     struct passwd *l_pass;
@@ -172,13 +177,11 @@ static void init_chown (void)
 
 #define XTRACT(i) BY+chown_but[i].y, BX+chown_but[i].x, chown_but[i].ret_cmd, chown_but[i].flags, _(chown_but[i].text), 0, 0, NULL
 
-    tk_new_frame (ch_dlg, "b.");
     for (i = 0; i < BUTTONS-single_set; i++)
 	add_widget (ch_dlg, button_new (XTRACT (i)));
 
     /* Add the widgets for the file information */
 #define LX(i) chown_label [i].y, chown_label [i].x, "", NULL
-    tk_new_frame (ch_dlg, "l.");
     for (i = 0; i < LABELS; i++){
 	chown_label [i].l = label_new (LX (i));
 	add_widget (ch_dlg, chown_label [i].l);
@@ -203,21 +206,20 @@ static void init_chown (void)
     }
     endgrent ();
     
-    tk_new_frame (ch_dlg, "f.");
     add_widget (ch_dlg, l_group);
-    tk_new_frame (ch_dlg, "g.");
     add_widget (ch_dlg, l_user);	/* add listboxes to the dialogs */
-    tk_end_frame ();
 }
 
-void chown_done (void)
+static void
+chown_done (void)
 {
     if (need_update)
 	update_panels (UP_OPTIMIZE, UP_KEEPSEL);
     repaint_screen ();
 }
 
-static inline void do_chown (uid_t u, gid_t g)
+static inline void
+do_chown (uid_t u, gid_t g)
 {
     if (mc_chown (cpanel->dir.list [current_file].fname, u, g) == -1)
 	message (1, MSG_ERROR, _(" Couldn't chown \"%s\" \n %s "),
@@ -226,7 +228,8 @@ static inline void do_chown (uid_t u, gid_t g)
     do_file_mark (cpanel, current_file, 0);
 }
 
-static void apply_chowns (uid_t u, gid_t g)
+static void
+apply_chowns (uid_t u, gid_t g)
 {
     char *fname;
   
@@ -242,7 +245,8 @@ static void apply_chowns (uid_t u, gid_t g)
 
 #define chown_label(n,txt) label_set_text (chown_label [n].l, txt)
 
-void chown_cmd (void)
+void
+chown_cmd (void)
 {
     char *fname;
     struct stat sf_stat;
@@ -251,6 +255,8 @@ void chown_cmd (void)
     gid_t new_group;
     char  buffer [15];
 
+#if 0
+    /* Please no */
     if (!vfs_current_is_local ()) {
 	if (vfs_current_is_extfs ()) {
 	    message (1, _(" Oops... "),
@@ -262,6 +268,7 @@ void chown_cmd (void)
 	    return;
 	}
     }
+#endif
 
     do {			/* do while any files remaining */
 	init_chown ();
