@@ -119,7 +119,8 @@ int is_right;
 /* defined in this file may receive a 0 parameter if they are invoked */
 /* The drop down menu */
 
-WPanel *get_a_panel (WPanel *panel)
+static WPanel *
+get_a_panel (WPanel *panel)
 {
     if (panel)
 	return panel;
@@ -173,6 +174,11 @@ int view_file_at_line (char *filename, int plain_view, int internal, int start_l
     if (internal){
 	char view_entry [32];
 
+#ifdef HAVE_GNOME
+	if (!gmc_view (filename, start_line)){
+	    view (0, filename, &move_dir, start_line);
+	}
+#else
 	if (start_line != 0)
 	    sprintf (view_entry, "View:%d", start_line);
 	else
@@ -182,6 +188,7 @@ int view_file_at_line (char *filename, int plain_view, int internal, int start_l
 	    view (0, filename, &move_dir, start_line);
 	    repaint_screen ();
 	}
+#endif
     } else {
 	char *localcopy;
 	
@@ -242,14 +249,16 @@ static void do_view_cmd (WPanel *panel, int normal)
     
     /* Directories are viewed by changing to them */
     if (S_ISDIR (selection (panel)->buf.st_mode) ||
-	link_isdir (selection (panel))){
+	link_isdir (selection (panel))) {
 	if (confirm_view_dir && (panel->marked || panel->dirs_marked)){
 	    if (query_dialog (_(" CD "), _("Files tagged, want to cd?"),
 			      0, 2, _("&Yes"), _("&No")) == 1){
 		return;
 	    }
 	}
-	do_cd (selection (panel)->fname, cd_exact);
+	if (!do_cd (selection (panel)->fname, cd_exact))
+	    message (1, MSG_ERROR, _("Could not change directory") );
+
 	return;
 	
     }
@@ -619,13 +628,16 @@ void unselect_cmd (void)
 static int check_for_default(char *default_file, char *file)
 {
     struct stat s;
+    long   count = 0;
+    double bytes = 0;
+    
     if (mc_stat (file, &s)){
 	if (mc_stat (default_file, &s)){
 	    return -1;
 	}
 	create_op_win (OP_COPY, 0);
         file_mask_defaults ();
-	copy_file_file (default_file, file, 1);
+	copy_file_file (default_file, file, 1, &count, &bytes, 1);
 	destroy_op_win ();
     }
     return 0;
@@ -706,10 +718,13 @@ void quick_chdir_cmd (void)
     if (!target)
 	return;
 
+#ifndef HAVE_GNOME
     if (get_current_type () == view_tree)
 	tree_chdir (the_tree, target);
     else
-	do_cd (target, cd_exact);
+#endif
+        if (!do_cd (target, cd_exact))
+	    message (1, MSG_ERROR, _("Could not change directory") );
     free (target);
 }
 
@@ -722,7 +737,8 @@ void reselect_vfs (void)
     if (!target)
 	return;
 
-    do_cd (target, cd_exact);
+    if (!do_cd (target, cd_exact))
+        message (1, MSG_ERROR, _("Could not change directory") );
     free (target);
 }
 #endif
@@ -940,8 +956,10 @@ view_other_cmd (void)
 	reset_shell_mode ();
 	noecho ();
 #endif
+#ifndef HAVE_X
 	keypad(stdscr, FALSE);
 	endwin ();
+#endif
 	if (!status_using_ncurses)
 	    do_exit_ca_mode ();
 	mc_raw_mode ();
@@ -969,9 +987,9 @@ view_other_cmd (void)
 	if (!status_using_ncurses)
 	    do_enter_ca_mode ();
 
+#ifndef HAVE_X	
 	reset_prog_mode ();
 	keypad(stdscr, TRUE);
-#ifndef HAVE_X	
 	if (use_mouse_p)
 	    init_mouse ();
         if (alternate_plus_minus)
@@ -989,8 +1007,10 @@ view_other_cmd (void)
 				       LINES-keybar_visible-1);
 	}
 #endif
+#ifndef HAVE_X
         touchwin (stdscr);
-
+#endif
+	
 	/* prevent screen flash when user did 'exit' or 'logout' within
 	   subshell */
 	if (!quit)
@@ -1326,94 +1346,28 @@ void quick_cd_cmd (void)
         free (p);
 }
 
-#ifdef SCO_FLAVOR
-#undef DUSUM_USEB
-#undef DUSUM_FACTOR
-#endif /* SCO_FLAVOR */
-
-#ifdef HAVE_DUSUM
-void dirsizes_cmd (void)
+void 
+dirsizes_cmd (void)
 {
     WPanel *panel = cpanel;
-    int i, j = 0;
-    char *cmd, *p, *q, *r;
-    FILE *f;
-#ifdef DUSUM_USEB
-#   define dirsizes_command "du -s -b "
-#else
-#   define dirsizes_command "du -s "
-#endif
-#ifndef DUSUM_FACTOR
-#    define DUSUM_FACTOR 512
-#endif
+    int i;
+    long marked;
+    double total;
 
-    if (!vfs_current_is_local ())
-        return;
-    for (i = 0; i < panel->count; i++)
-        if (S_ISDIR (panel->dir.list [i].buf.st_mode))
-            j += strlen (panel->dir.list [i].fname) + 1;
-    if (!j)
-        return;
-    cmd = xmalloc (strlen (dirsizes_command) + j + 1, "dirsizes_cmd");
-    strcpy (cmd, dirsizes_command);
-    p = strchr (cmd, 0);
-    for (i = 0; i < panel->count; i++)
-        if (S_ISDIR (panel->dir.list [i].buf.st_mode) && 
-            strcmp (panel->dir.list [i].fname, "..")) {
-            strcpy (p, panel->dir.list [i].fname);
-            p = strchr (p, 0);
-            *(p++) = ' ';
-        }
-    *(--p) = 0;
-    open_error_pipe ();
-    f = popen (cmd, "r");
-    free (cmd);
-    if (f != NULL) {
-        /* Assume that du will display the directories in the order 
-         * I've passed to it :( 
-         */
-        i = 0;
-        p = xmalloc (1024, "dirsizes_cmd");
-        while (fgets (p, 1024, f)) {
-            j = atoi (p) * DUSUM_FACTOR;
-            for (q = p; *q && *q != ' ' && *q != '\t'; q++);
-            while (*q == ' ' || *q == '\t')
-                q++;
-            r = strchr (q, '\n');
-            if (r == NULL)
-                r = strchr (q, 0);
-    	    for (; i < panel->count; i++)
-                if (S_ISDIR (panel->dir.list [i].buf.st_mode))
-                    if (!strncmp (q, panel->dir.list [i].fname,
-                        r - q)) {
-                        if (panel->dir.list [i].f.marked)
-                            panel->total += j - 
-			    ((panel->has_dir_sizes) ? panel->dir.list [i].buf.st_size : 0); 
-                        panel->dir.list [i].buf.st_size = j;
-                        break;
-                    }
-            if (i == panel->count)
-                break;
-        }
-	free (p);
-        if (pclose (f) < 0)
-#ifndef SCO_FLAVOR
-	    message (0, _("Show directory sizes"), _("Pipe close failed"));
-	else
-#else /* SCO_FLAVOR */
- 	/* 
- 	**	SCO reports about error while all seems to be ok. Just ignore it...
- 	**	(alex@bcs.zaporizhzhe.ua)
- 	*/
- 	;
-#endif /* SCO_FLAVOR */
-	    panel->has_dir_sizes = 1;
-	close_error_pipe (0, 0);
-	paint_panel (panel);
-    } else
-        close_error_pipe (1, _("Cannot invoke du command."));
+    for (i = 0; i < panel->count; i++) 
+	if (S_ISDIR (panel->dir.list [i].buf.st_mode) &&
+	         ((panel->dirs_marked && panel->dir.list [i].f.marked) || 
+                   !panel->dirs_marked) &&
+	         strcmp (panel->dir.list [i].fname, "..") != 0) {
+	    total = 0.0l;
+	    compute_dir_size (panel->dir.list [i].fname, &marked, &total);
+            panel->dir.list [i].buf.st_size = (long)total;
+	    panel->dir.list [i].f.dir_size_computed = 1;
+	}
+	
+    recalculate_panel_summary (panel);
+    paint_panel (panel);
 }
-#endif
 
 void
 save_setup_cmd (void)
