@@ -35,7 +35,7 @@
 #include "dlg.h"		/* draw_box, yes I know, it's silly */
 #include "background.h"		/* we_are_background definition */
 
-/* "$Id: dialog.c,v 1.2 1998/04/28 04:29:29 unammx Exp $" */
+/* "$Id: dialog.c,v 1.3 1998/12/02 05:18:39 unammx Exp $" */
 
 Refresh *refresh_list = 0;
 
@@ -90,17 +90,4 @@ void do_refresh (void)
     }
 }
 
-/* Poor man's window puts, it doesn't handle auto-wrap */
-void my_wputs (int y, int x, char *text)
-{
-    char p;
-
-    move (y, x);
-    while ((p = *text++) != 0){
-	if (p == '\n')
-	    move (++y, x);
-	else 
-	    addch ((unsigned char)p);
-    }
-}
 
