@@ -38,8 +38,8 @@
 #include "win.h"
 #include "color.h"
 #include "global.h"
-
-extern int verbose;		/* Should be in a more sensible header file */
+#include "setup.h"
+#include "find.h"
 
 /* Dialog manager and widgets */
 #include "dlg.h"
@@ -55,10 +55,6 @@ extern int verbose;		/* Should be in a more sensible header file */
 #include "cmd.h"		/* view_file_at_line */
 #include "../vfs/vfs.h"
 
-#ifdef HAVE_XVIEW
-#include "xvmain.h"
-#endif
-
 #ifndef PORT_HAS_FLUSH_EVENTS
 #    define x_flush_events()
 #endif
@@ -232,9 +228,14 @@ find_par_start:
 	add_widgetl (find_dlg, label_new (3, 3, labs[0], "label-start"), XV_WLAY_NEXTCOLUMN);
 
     run_dlg (find_dlg);
-    if (find_dlg->ret_value == B_CANCEL)
+
+    switch (find_dlg->ret_value){
+    case B_CANCEL:
 	return_value = 0;
-    else if (find_dlg->ret_value == B_TREE){
+	break;
+
+#ifndef HAVE_GNOME
+    case B_TREE:
 	temp_dir = strdup (in_start->buffer);
 	destroy_dlg (find_dlg);
 	free (in_start_dir);
@@ -249,7 +250,10 @@ find_par_start:
 	    in_start_dir = temp_dir;
 	/* Warning: Dreadful goto */
 	goto find_par_start;
-    } else {
+	break;
+#endif
+	
+    default:
 	return_value = 1;
 	*start_dir = strdup (in_start->buffer);
 	*pattern   = strdup (in_name->buffer);
@@ -383,7 +387,7 @@ locate_egrep (void)
  * Search with egrep the global (FIXME) content_pattern string in the
  * DIRECTORY/FILE.  It will add the found entries to the find listbox.
  */
-void
+static void
 search_content (Dlg_head *h, char *directory, char *filename)
 {
     struct stat s;
@@ -513,8 +517,12 @@ do_search (struct Dlg_head *h)
 		    return;
 		}
 		if (find_ignore_dirs){
+                    int found;
 		    char *temp_dir = copy_strings (":", tmp, ":", 0);
-		    if (strstr (find_ignore_dirs, temp_dir))
+
+                    found = strstr (find_ignore_dirs, temp_dir) != 0;
+                    free (temp_dir);
+		    if (found)
 			free (tmp);
 		    else
 			break;
@@ -545,9 +553,6 @@ do_search (struct Dlg_head *h)
     if (strcmp (dp->d_name, ".") == 0 ||
 	strcmp (dp->d_name, "..") == 0){
 	dp = mc_readdir (dirp);
-#ifdef HAVE_XVIEW
-	xv_post_proc (h, (void (*)(void *))do_search, (void *)h);
-#endif		
 	return;
     }
     
@@ -587,9 +592,6 @@ do_search (struct Dlg_head *h)
 #else
         }
     }
-#ifdef HAVE_XVIEW
-    xv_post_proc (h, (void (*)(void *))do_search, (void *)h);
-#endif
 #endif
     x_flush_events ();
 }
@@ -797,9 +799,6 @@ find_file (char *start_dir, char *pattern, char *content, char **dirname,  char
     init_find_vars ();
     push_directory (start_dir);
 
-#ifdef HAVE_XVIEW
-    xv_post_proc (find_dlg, (void (*)(void *))do_search, (void *)find_dlg);
-#endif    
     run_dlg (find_dlg);
 
     return_value = find_dlg->ret_value;
@@ -863,10 +862,10 @@ find_file (char *start_dir, char *pattern, char *content, char **dirname,  char
     		clean_dir (list, cpanel->count);
 	    list->list [next_free].fnamelen = strlen (name);
 	    list->list [next_free].fname = name;
-	    list->list [next_free].cache = NULL;
 	    file_mark (cpanel, next_free, 0);
 	    list->list [next_free].f.link_to_dir = link_to_dir;
 	    list->list [next_free].f.stalled_link = stalled_link;
+	    list->list [next_free].f.dir_size_computed = 0;
 	    list->list [next_free].buf = buf;
 	    next_free++;
            if (!(next_free & 15))
@@ -876,7 +875,6 @@ find_file (char *start_dir, char *pattern, char *content, char **dirname,  char
 	    cpanel->count = next_free;
 	    cpanel->is_panelized = 1;
 	    cpanel->dirs_marked = 0;
-	    cpanel->has_dir_sizes = 0;
 	    cpanel->marked = 0;
 	    cpanel->total = 0;
 	    cpanel->top_file = 0;
