@@ -33,14 +33,13 @@
       * If TIOCGWINSZ supported, make it available here, because window-
       * resizing code depends on it...
       */
-#    ifdef __QNX__              /* Maybe not only QNX-specific... */
 #	include <sys/ioctl.h>
-#    endif
 #endif
 #ifdef HAVE_UNISTD_H
 #   include <unistd.h>
 #endif
 #include <signal.h>
+#include <glib.h>
 #include "tty.h"
 #include "mad.h"
 #include "util.h"		/* Needed for the externs */
@@ -70,12 +69,12 @@
 #include "info.h"		/* The Info widget */
 #include "view.h"		/* The view widget */
 
-#define WANT_DEFAULTS
+#define WANT_WIDGETS
 #include "setup.h"		/* For save_setup() */
 
 #include "x.h"
 
-/* "$Id: layout.c,v 1.10 1998/09/29 12:07:13 pavel Exp $" */
+/* "$Id: layout.c,v 1.15 1998/12/26 22:56:02 norbert Exp $" */
 
 /* Controls the display of the rotating dash on the verbose mode */
 int nice_rotating_dash = 1;
@@ -477,14 +476,6 @@ static void init_layout (void)
 	check_options [i].widget = check_new (8 - i, 7 + first_width, XTRACT(i));
 	add_widgetl (layout_dlg, check_options [i].widget, XV_WLAY_BELOWCLOSE);
     }
-#ifdef HAVE_XVIEW
-    add_widgetl (layout_dlg, label_new (2, 7 + first_width, _("Other options"), "oo"),
-        XV_WLAY_NEXTCOLUMN);
-    add_widgetl (layout_dlg, label_new (8, 5, _("Highlight..."), "hl"),
-        XV_WLAY_NEXTCOLUMN);
-    add_widgetl (layout_dlg, label_new (2, 5, _("Panel split"), "ps"),
-        XV_WLAY_NEXTCOLUMN);
-#endif        
     check_options [8].widget = check_new (10, 6, XTRACT(8));
     add_widgetl (layout_dlg, check_options [8].widget, XV_WLAY_BELOWCLOSE);
     check_options [7].widget = check_new (9, 6, XTRACT(7));
@@ -634,7 +625,8 @@ void done_screen ()
 }
 #endif /* HAVE_X */
 
-void panel_do_cols (int index)
+static void
+panel_do_cols (int index)
 {
     if (get_display_type (index) == view_listing)
 	set_panel_formats ((WPanel *) panels [index].widget);
@@ -661,10 +653,6 @@ setup_panels (void)
     }
 
     load_hint ();
-#ifdef HAVE_XVIEW
-    panel_do_cols (0);
-    panel_do_cols (1);
-#endif    
 }
 
 #else
@@ -760,7 +748,8 @@ void flag_winch (int dummy)
 void edit_adjust_size (Dlg_head * h);
 
 #ifdef PORT_NEEDS_CHANGE_SCREEN_SIZE
-void low_level_change_screen_size (void)
+static void
+low_level_change_screen_size (void)
 {
 #if defined(HAVE_SLANG) || NCURSES_VERSION_MAJOR >= 4
 #if defined TIOCGWINSZ && !defined SCO_FLAVOR
@@ -828,7 +817,6 @@ void change_screen_size (void)
 }
 #endif /* HAVE_X */
 
-extern int verbose;
 static int ok_to_refresh = 1;
 
 void use_dash (int flag)
@@ -854,18 +842,16 @@ void set_hintbar(char *str)
     }
 }
 
-void print_vfs_message(char *msg, ...)
+void print_vfs_message (char *msg, ...)
 {
     va_list ap;
-    char str[128];
+    char str [128];
 
-    va_start(ap, msg);
-    vsnprintf(str, 126, msg, ap);
-    /* Before you kill me for using non-portable vsnprintf... It is
-       neccessary: vfs layer may print arbitrary long messages (they
-       contain pathname). If you know how to solve it, please do so,
-       but this is probably exploitable buffer overrun.) */
-    va_end(ap);
+    va_start (ap, msg);
+    
+    g_vsnprintf (str, 126, msg, ap);
+    va_end (ap);
+    
     if (midnight_shutdown || !the_hint || !the_hint->widget.parent)
 	return;
     
@@ -979,9 +965,6 @@ void set_display_type (int num, int type)
 		    x = first_panel_size;
 	    }
 	}
-#ifdef HAVE_TK
-	tk_evalf ("container_clean %s", panel->widget.wcontainer);
-#endif
     }
 
     new_widget = 0;
@@ -1055,7 +1038,6 @@ void set_display_type (int num, int type)
 	    current_panel = num == 0 ? right_panel : left_panel;
 }
 
-#ifndef HAVE_XVIEW
 /* This routine is deeply sticked to the two panels idea.
    What should it do in more panels. ANSWER - don't use it
    in any multiple panels environment. */
@@ -1152,7 +1134,6 @@ void swap_panels ()
         panels [1].type = tmp_type;
     }
 }
-#endif
 
 int get_display_type (int index)
 {
