@@ -79,6 +79,11 @@
 #include <fcntl.h>	/* For O_RDWR */
 #include <signal.h>
 
+#ifdef HAVE_CORBA
+#    include <libgnorba/gnorba.h>
+#    include "gcorba.h"
+#endif
+
 /* Program include files */
 #include "x.h"
 #include "mad.h"
@@ -131,10 +136,10 @@
 #include "../vfs/vfs.h"
 #include "../vfs/extfs.h"
 
-
+#include <glib.h>
 #include "popt.h"
 
-/* "$Id: main.c,v 1.50 1998/10/05 18:07:26 norbert Exp $" */
+/* "$Id: main.c,v 1.63 1998/12/30 02:51:13 unammx Exp $" */
 
 /* When the modes are active, left_panel, right_panel and tree_panel */
 /* Point to a proper data structure.  You should check with the functions */
@@ -238,10 +243,6 @@ WLabel *the_hint;
 /* The button bar */
 WButtonBar *the_bar;
 
-#ifdef HAVE_X
-WButtonBar *the_bar2;
-#endif
-
 /* For slow terminals */
 int slow_terminal = 0;
 
@@ -290,6 +291,12 @@ char *home_dir;
 char *other_dir = 0;
 char *this_dir = 0;
 
+/* If this is true, then when browsing the tree the other window will
+ * automatically reload it's directory with the contents of the currently
+ * selected directory.
+ */
+int xtree_mode = 0;
+
 /* If true, then print on stdout the last directory we were at */
 static int print_last_wd = 0;
 static char *last_wd_string;
@@ -366,11 +373,13 @@ void
 try_to_select (WPanel *panel, char *name)
 {
     Xtry_to_select (panel, name);
+#ifndef HAVE_X
     select_item (panel);
+#endif
     display_mini_info (panel);
 }
 
-void
+static void
 reload_panelized (WPanel *panel)
 {
     int i, j;
@@ -906,18 +915,6 @@ directory_history_add (WPanel * panel, char *s)
     panel_update_marks (panel);
 }
 
-/* Translate ftp://user:password@host/directory to 
-              /#ftp:user:password@host/directory.
- */
-static char *
-translate_url_to_new_syntax (const char *p)
-{
-    if (strncmp (p, "ftp://", 6) == 0)
-        return copy_strings ("/#ftp:", p + 6, 0);
-    else
-        return strdup (p);
-}
-
 /*
  *  If we moved to the parent directory move the selection pointer to
  *  the old directory name; If we leave VFS dir, remove FS specificator.
@@ -925,7 +922,7 @@ translate_url_to_new_syntax (const char *p)
  *
  *  You do _NOT_ want to add any vfs aware code here. <pavel@ucw.cz>
  */
-char*
+static char*
 get_parent_dir_name (char *cwd, char *lwd)
 {
     char *p;
@@ -937,7 +934,7 @@ get_parent_dir_name (char *cwd, char *lwd)
 }
 
 /* Changes the current panel directory */
-int
+static int
 _do_panel_cd (WPanel *panel, char *new_dir, enum cd_enum cd_type)
 {
     char *directory, *olddir;
@@ -949,7 +946,7 @@ _do_panel_cd (WPanel *panel, char *new_dir, enum cd_enum cd_type)
     struct vfs_stamping *parent;
 #endif    
     olddir = strdup (panel->cwd);
-    translated_url = new_dir = translate_url_to_new_syntax (new_dir);
+    translated_url = new_dir = vfs_translate_url (new_dir);
 
     /* Convert *new_path to a suitable pathname, handle ~user */
     
@@ -997,7 +994,7 @@ _do_panel_cd (WPanel *panel, char *new_dir, enum cd_enum cd_type)
     panel->dirs_marked = 0;
     panel->total = 0;
     panel->searching = 0;
-    try_to_select (panel, get_parent_dir_name(panel->cwd, olddir));
+    try_to_select (panel, get_parent_dir_name (panel->cwd, olddir));
     load_hint ();
     panel_update_contents (panel);
     
@@ -1127,7 +1124,7 @@ maybe_cd (int char_code, int move_up_dir)
     return 0;
 }
 
-void
+static void
 set_sort_to (WPanel *p, sortfn *sort_order)
 {
     p->sort_type = sort_order;
@@ -1173,6 +1170,7 @@ sort_cmd (void)
     do_re_sort (p);
 }
 
+#ifndef HAVE_GNOME
 static void
 tree_box (void)
 {
@@ -1184,6 +1182,7 @@ tree_box (void)
 	free (sel_dir);
     }
 }
+#endif
 
 #if SOMEDAY_WE_WILL_FINISH_THIS_CODE
 static void
@@ -1197,8 +1196,8 @@ static void
 #endif
 
 #ifdef HAVE_GNOME
-void init_menu () {};
-void done_menu () {};
+void init_menu (void) {};
+void done_menu (void) {};
 #else
 /* NOTICE: hotkeys specified here are overriden in menubar_paint_idx (alex) */
 static menu_entry PanelMenu [] = {
@@ -1276,17 +1275,15 @@ static menu_entry CmdMenu [] = {
      * as a panel still has some problems, I have not yet finished
      * the WTree widget port, sorry.
      */
+#ifndef HAVE_GNOME
     { ' ', N_("&Directory tree"),               'D', tree_box },
+#endif
     { ' ', N_("&Find file            M-?"),     'F', find_cmd },
-#ifndef HAVE_XVIEW    
     { ' ', N_("s&Wap panels          C-u"),     'W', swap_cmd },
     { ' ', N_("switch &Panels on/off C-o"),     'P', view_other_cmd },
-#endif    
     { ' ', N_("&Compare directories  C-x d"),   'C', compare_dirs_cmd },
     { ' ', N_("e&Xternal panelize    C-x !"),   'X', external_panelize },
-#ifdef HAVE_DUSUM
     { ' ', N_("show directory s&Izes"),         'I', dirsizes_cmd },
-#endif
     { ' ', "", ' ', 0 },
     { ' ', N_("command &History"),              'H', history_cmd },
     { ' ', N_("di&Rectory hotlist    C-\\"),    'R', quick_chdir_cmd },
@@ -1344,7 +1341,6 @@ init_menu (void)
     MenuBar [1] = create_menu (_(" &File "), FileMenu, menu_entries (FileMenu));
     MenuBar [2] = create_menu (_(" &Command "), CmdMenu, menu_entries (CmdMenu));
     MenuBar [3] = create_menu (_(" &Options "), OptMenu, menu_entries (OptMenu));
-#ifndef HAVE_XVIEW
 #ifdef HAVE_X
     MenuBar [4] = create_menu (_(" &Right "), RightMenu, menu_entries (PanelMenu));
 #else
@@ -1353,7 +1349,6 @@ init_menu (void)
     for (i = 0; i < 5; i++)
 	MenuBarEmpty [i] = create_menu (MenuBar [i]->name, 0, 0);
 #endif /* HAVE_X */
-#endif /* ! HAVE_XVIEW */
 }
 
 void
@@ -1361,15 +1356,10 @@ done_menu (void)
 {
     int i;
 
-#ifndef HAVE_XVIEW
     for (i = 0; i < 5; i++){
 	destroy_menu (MenuBar [i]);
 #ifndef HAVE_X
 	destroy_menu (MenuBarEmpty [i]);
-#endif
-#else
-    for (i = 0; i < 4; i++){
-	destroy_menu (MenuBar [i]);
 #endif
     }
 }
@@ -1463,7 +1453,7 @@ translated_mc_chdir (char *dir)
 {
 	char *newdir;
 
-	newdir = translate_url_to_new_syntax (dir);
+	newdir = vfs_translate_url (dir);
 	mc_chdir (newdir);
 	free (newdir);
 }
@@ -1534,12 +1524,7 @@ create_panels (void)
     the_hint->widget.cols = COLS;
 #endif
     
-#ifndef HAVE_XVIEW
     the_menubar = menubar_new (0, 0, COLS, MenuBar, 5);
-#else
-    the_menubar = menubar_new (0, 0, COLS, MenuBar + 1, 3);
-    the_bar2    = buttonbar_new (keybar_visible);
-#endif
 }
 #endif
 
@@ -1676,7 +1661,8 @@ static void do_suspend_cmd (void)
     edition_post_exec ();
 }
 
-void suspend_cmd (void)
+void
+suspend_cmd (void)
 {
     save_cwds_stat ();
     do_suspend_cmd ();
@@ -1684,7 +1670,8 @@ void suspend_cmd (void)
     do_refresh ();
 }
 
-void init_labels (Widget *paneletc)
+static void
+init_labels (Widget *paneletc)
 {
     define_label (midnight_dlg, paneletc, 1, _("Help"), help_cmd);
     define_label (midnight_dlg, paneletc, 2, _("Menu"), user_menu_cmd);
@@ -1692,7 +1679,6 @@ void init_labels (Widget *paneletc)
     define_label (midnight_dlg, paneletc, 10, _("Quit"), (voidfn) quit_cmd);
 }
 
-#ifndef HAVE_XVIEW
 static key_map ctl_x_map [] = {
     { XCTRL('c'),   (callfn) quit_cmd },
 #ifdef USE_VFS
@@ -1788,7 +1774,6 @@ static key_map default_map [] = {
     { XCTRL('g'), nothing },
     { 0, 0 },
 };
-#endif
 
 #ifndef HAVE_X
 static void setup_sigwinch ()
@@ -1913,7 +1898,8 @@ static void done_mc_profile ()
  * change to use npanels, just loop over the number of panels
  * and use get_panel_widget (i) and make the test done below
  */
-void make_panels_dirty ()
+static void
+make_panels_dirty ()
 {
     if (cpanel->dirty)
 	panel_update_contents (cpanel);
@@ -1929,13 +1915,12 @@ void make_panels_dirty ()
 #   define check_key_backslash(x) ((x) == '\\')
 #endif
 
-int midnight_callback (struct Dlg_head *h, int id, int msg)
+int
+midnight_callback (struct Dlg_head *h, int id, int msg)
 {
     int i;
     
     switch (msg){
-#ifndef HAVE_XVIEW
-
 	/* Speed up routine: now, we just set the  */
     case DLG_PRE_EVENT:
 	make_panels_dirty ();
@@ -2041,7 +2026,6 @@ int midnight_callback (struct Dlg_head *h, int id, int msg)
 	}
 	return MSG_NOT_HANDLED;
 	
-#endif
 #ifndef HAVE_X
 	/* We handle the special case of the output lines */
     case DLG_DRAW:
@@ -2076,10 +2060,6 @@ xtoolkit_panel_setup ()
     the_prompt->widget.area = AREA_BOTTOM;
     the_bar->widget.wcontainer = containers [0];
     the_bar->widget.area = AREA_TOP;
-#ifdef HAVE_XVIEW
-    the_bar2->widget.wcontainer = containers [1];
-    the_bar2->widget.area = AREA_TOP;
-#endif
     get_panel_widget (0)->wcontainer = containers [0];
     get_panel_widget (0)->area = AREA_RIGHT;
     get_panel_widget (1)->wcontainer = containers [1];
@@ -2124,18 +2104,14 @@ setup_panels_and_run_mc ()
     int first, second;
 
     xtoolkit_panel_setup ();
-    tk_new_frame (midnight_dlg, "p.");
 #ifndef HAVE_X
     add_widget (midnight_dlg, the_hint);
 #endif /* HAVE_X */
     load_hint ();
     add_widgetl (midnight_dlg, cmdline, XV_WLAY_RIGHTOF);
     add_widgetl (midnight_dlg, the_prompt, XV_WLAY_DONTCARE);
-    tk_end_frame ();
     add_widget (midnight_dlg, the_bar);
-#ifdef HAVE_XVIEW
-    add_widget (midnight_dlg, the_bar2);
-#endif
+
     if (boot_current_is_left){
 	first = 1;
 	second = 0;
@@ -2155,7 +2131,7 @@ setup_panels_and_run_mc ()
 }
 
 /* result must be free'd (I think this should go in util.c) */
-char *
+static char *
 prepend_cwd_on_local (char *filename)
 {
     char *d;
@@ -2177,7 +2153,7 @@ prepend_cwd_on_local (char *filename)
 #ifdef USE_INTERNAL_EDIT
 void edit (const char *file_name, int startline);
 
-int
+static int
 mc_maybe_editor_or_viewer (void)
 {
     char *path;
@@ -2344,7 +2320,7 @@ init_sigfatals (void)
 #define CONTROL_FILE "/tmp/mc.%d.control"
 char control_file [sizeof (CONTROL_FILE) + 8];
 
-void
+static void
 OS_Setup ()
 {
     char   *termvalue;
@@ -2419,61 +2395,6 @@ sigchld_handler_no_subshell (int sig)
 #endif /* ! HAVE_X  */
 }
 
-#if 0
-void
-mc_fatal_signal (int signum)
-{
-    volatile int x;
-    char     cmd;
-    pid_t    pid;
-    char     *args [4] = { "gdb", NULL, NULL, NULL };
-    char     pid [20];
-
-    sprintf (buf, "%d", getpid ());
-    fprintf (stderr,
-	     "Midnight Commander fatal error, PID=%d\n"
-	     "What to do: [e]xit, [s]tack trace, [a]ttach to process\n", getpid ());
-
-    read (1, &cmd, 1);
-    if (cmd == 'a'){
-	for (x = 1; x;)
-	    ;
-    }
-    if (cmd == 's'){
-	args [1] = program_name;
-	args [2] = buf;
-	pid = fork ();
-	if (pid == -1){
-	    fprintf (stderr, "Could not fork, exiting\n");
-	    exit (0);
-	}
-	if (pid == 0){
-	    stack_trace (args);
-	} else {
-	    while (1)
-		;
-	}
-    }
-    exit (0);
-}
-
-void
-init_sigfatals (void)
-{
-    struct sigaction sa;
-
-    sa.sa_hanlder = mc_fatal_signal;
-    sa.sa_mask    = 0;
-    sa.sa_flags   = 0;
-    
-    sigaction (SIGSEGV, &sa, NULL);
-    sigaction (SIGBUS,  &sa, NULL);
-    sigaction (SIGFPE,  &sa, NULL);
-}
-#else
-#define init_sigfatals() 
-#endif
-
 void
 init_sigchld (void)
 {
@@ -2498,11 +2419,12 @@ init_sigchld (void)
 
 #endif /* _OS_NT, __os2__, UNIX */
 
+#ifndef HAVE_X
 #if defined(HAVE_SLANG) && !defined(OS2_NT)
     extern int SLtt_Try_Termcap;
 #endif
+#endif
 
-#ifndef PORT_WANTS_ARGP
 static void
 print_mc_usage (void)
 {
@@ -2552,7 +2474,6 @@ print_mc_usage (void)
 #endif
     );
 }
-#endif /* PORT_WANTS_ARGP */
 
 static void
 print_color_usage (void)
@@ -2672,132 +2593,25 @@ process_args (int c, char *option_arg)
     }
 }
 
-#ifdef PORT_WANTS_ARGP
-static struct argp_option argp_options [] = {
-#ifdef WITH_BACKGROUND
-    { "background",	'B', NULL, 0, N_("[DEVEL-ONLY: Debug the background code]"), 0 },
-#endif
-#if defined(HAVE_SLANG) && defined(OS2_NT)
-    { "createcmdfile",	'S', "CMDFILE", , 0, N_("Create command file to set default directory upon exit."), 1 },
-#endif			     
-    { "color",          'c', NULL, 0, N_("Force color mode."), 0 },
-    { "colors", 	'C', "COLORS", 0, N_("Specify colors (use --help-colors to get a list)."), 1 },
-#ifdef HAVE_SUBSHELL_SUPPORT
-    { "dbgsubshell", 	'X', NULL, 0, N_("[DEVEL-ONLY: Debug the subshell]"), 0 },
-#endif
-    { "edit", 		'e', "EDIT", 0, N_("Startup the internal editor."), 1 },
-    { "help", 		'h', NULL, 0, N_("Shows this help message."), 0 },
-    { "help-colors",	'H', NULL, 0, N_("Help on how to specify colors."), 0 },
-#ifdef USE_NETCODE
-    { "ftplog", 	'l', "FTPLOG", 0, N_("Log ftpfs commands to the file."), 1 },
-#endif
-    { "libdir", 	'f', NULL, 0, N_("Prints out the configured paths."), 0 },
-    { NULL, 		'm', NULL, OPTION_HIDDEN, NULL, 0 },
-    { "nocolor", 	'b', NULL, 0, N_("Force black and white display."), 0 },
-    { "nomouse", 	'd', NULL, 0, N_("Disable mouse support."), 0 },
-#ifdef HAVE_SUBSHELL_SUPPORT
-    { "subshell", 	'U', NULL, 0, N_("Force the concurrent subshell mode"), 0 },
-    { "nosubshell", 	'u', NULL, 0, N_("Disable the concurrent subshell mode."), 0 },
-    { "forceexec", 	'r', NULL, 0, N_("Force subshell execution."), 0 },
-#endif
-    { "printwd", 	'P', NULL, 0, N_("At exit, print the last working directory."), 0 },
-    { "resetsoft", 	'k', NULL, 0, N_("Reset softkeys (HP terminals only) to their terminfo/termcap default."), 0},
-    { "slow",           's', NULL, 0, N_("Disables verbose operation (for slow terminals)."), 0 },
-#if defined(HAVE_SLANG) && !defined(OS2_NT)
-    { "stickchars",	'a', NULL, 0, N_("Use simple symbols for line drawing."), 0 },
-#endif
-#ifdef HAVE_SUBSHELL_SUPPORT
-#endif
-#if defined(HAVE_SLANG) && !defined(OS2_NT)
-    { "termcap", 	't', NULL, 0, N_("Activate support for the TERMCAP variable."), 0 },
-#endif
-    { "version", 	'V', NULL, 0, N_("Report version and configuration options."), 0 },
-    { "view", 		'v', NULL, 0, N_("Start up into the viewer mode."), 0 },
-    { "xterm", 		'x', NULL, 0, N_("Force xterm mouse support and screen save/restore"), 0 },
-    { "geometry",       GEOMETRY_KEY,  "GEOMETRY", 0, N_("Geometry for the window"), 0 },
-    { "nowindows",      NOWIN_KEY, NULL, 0, N_("No windows opened at startup"), 0 },
-    { NULL, 		0,   NULL, 0, NULL },
-};
-
-GList *directory_list = 0;
-GList *geometry_list  = 0;
-int   nowindows;
-
-static error_t
-parse_an_arg (int key, char *arg, struct argp_state *state)
+#ifdef HAVE_GNOME
+static void parse_an_arg (poptContext state,
+			  enum poptCallbackReason reason,
+			  const struct poptOption *opt,
+			  const char *arg, void *data)
 {
-	switch (key){
-#ifdef WITH_BACKGROUND
-	case 'B':
-	    background_wait = 1;
-	    return 0;
-#endif
-	case 'b':
-	    disable_colors = 1;
-	    return 0;
-	    
-	case 'P':
-	    print_last_wd = 1;
-	    return 0;
-	    
-	case 'k':
-	    reset_hp_softkeys = 1;
-	    return 0;
-
-	case 's':
-	    slow_terminal = 1;
-	    return 0;
-
-	case 'a':
-	    force_ugly_line_drawing = 1;
-	    return 0;
-
-	case 'x':
-	    force_xterm = 1;
-	    return 0;
-	    
-#if defined(HAVE_SLANG) && !defined(OS2_NT)
-	case 't':
-	    SLtt_Try_Termcap = 1;
-	    return 0;
-#endif
-
-	case GEOMETRY_KEY:
-	    geometry_list = g_list_append (geometry_list, arg);
-	    return 0;
-
-	case NOWIN_KEY:
-	    nowindows = 1;
-	    
-	case ARGP_KEY_ARG:
-	    break;
-
-	case ARGP_KEY_INIT:
-	case ARGP_KEY_FINI:
-	    return 0;
-	    
-	default:
-	    process_args (key, arg);
-	}
-
-	if (arg){
-	    if (edit_one_file)
-		edit_one_file = strdup (arg);
-	    else if (view_one_file)
-		view_one_file = strdup (arg);
-	    else 
-	        directory_list = g_list_append (directory_list, arg);
-	}
-	return 0;
+	process_args (opt->shortName, arg);
 }
 
-static struct argp mc_argp_parser = {
-	argp_options, parse_an_arg, N_("[this dir] [other dir]"), NULL, NULL, NULL, NULL
-};
+#endif
 
-#else 
+char *cmdline_geometry = NULL;
+int   nowindows = 0;
+char **directory_list = NULL;
 
-static struct poptOption argumentTable[] = {
+static struct poptOption argument_table [] = {
+#ifdef HAVE_GNOME
+	{ NULL, '\0', POPT_ARG_CALLBACK, parse_an_arg, 0},
+#endif
 #ifdef WITH_BACKGROUND
     { "background",	'B', POPT_ARG_NONE, 	&background_wait, 	 0 },
 #endif
@@ -2811,7 +2625,9 @@ static struct poptOption argumentTable[] = {
 #endif
     { "edit", 		'e', POPT_ARG_STRING, 	&edit_one_file, 	 0 },
 
+#ifndef HAVE_GNOME
     { "help", 		'h', POPT_ARG_NONE, 	NULL, 			 'h' },
+#endif
     { "help-colors",	'H', POPT_ARG_NONE, 	NULL, 			 'H' },
 #ifdef USE_NETCODE
     { "ftplog", 	'l', POPT_ARG_STRING, 	NULL, 			 'l' },
@@ -2833,12 +2649,18 @@ static struct poptOption argumentTable[] = {
 #ifdef HAVE_SUBSHELL_SUPPORT
     { "subshell", 	'U', POPT_ARG_NONE, 	NULL, 			  'U' },
 #endif
+#if !defined(HAVE_X)
 #if defined(HAVE_SLANG) && !defined(OS2_NT)
     { "termcap", 	't', 0, 		&SLtt_Try_Termcap, 	  0 },
+#endif
 #endif
     { "version", 	'V', 			POPT_ARG_NONE, NULL,      'V'},
     { "view", 		'v', 			POPT_ARG_STRING, &view_one_file, 0 },
     { "xterm", 		'x', 			POPT_ARG_NONE, &force_xterm, 0},
+#ifdef HAVE_GNOME
+    { "geometry", '\0', POPT_ARG_STRING, &cmdline_geometry, 0, N_("Geometry for the window"), N_("GEOMETRY")},
+    {"nowindows", '\0', POPT_ARG_NONE, &nowindows, 0, N_("No windows opened at startup"), NULL},
+#endif
 
     { NULL, 		0,			0, NULL, 0 }
 };
@@ -2848,16 +2670,38 @@ handle_args (int argc, char *argv [])
 {
     char   *tmp, *option_arg, *base;
     int    c;
-    poptContext   optCon;
+    poptContext   ctx;
 
-    optCon = poptGetContext ("mc", argc, argv, argumentTable, 0);
+#ifdef HAVE_GNOME
+#ifdef HAVE_CORBA
+    CORBA_Environment ev;
 
+    CORBA_exception_init (&ev);
+
+    orb = gnome_CORBA_init_with_popt_table (
+	    "gmc", VERSION, &argc, argv, argument_table, 0, &ctx, GNORBA_INIT_SERVER_FUNC, &ev);
+
+    corba_register_server ();
+#else
+    gnome_init_with_popt_table ("gmc", VERSION, argc, argv, argument_table, 0, &ctx);
+    gtk_widget_push_visual (gdk_imlib_get_visual ());
+    gtk_widget_push_colormap (gdk_imlib_get_colormap ());
+	
+#endif
+    poptResetContext (ctx);
+#else
+    ctx = poptGetContext ("mc", argc, argv, argument_table, 0);
+#endif
+
+#ifndef HAVE_X
 #ifdef USE_TERMCAP
     SLtt_Try_Termcap = 1;
 #endif
+#endif
 
-    while ((c = poptGetNextOpt (optCon)) > 0) {
-	option_arg = poptGetOptArg(optCon);
+#ifndef HAVE_GNOME
+    while ((c = poptGetNextOpt (ctx)) > 0){
+	option_arg = poptGetOptArg (ctx);
 
 	process_args (c, option_arg);
     }
@@ -2865,18 +2709,19 @@ handle_args (int argc, char *argv [])
     if (c < -1){
 	print_mc_usage ();
 	fprintf(stderr, "%s: %s\n", 
-		poptBadOption(optCon, POPT_BADOPTION_NOALIAS), 
-		poptStrerror(c));
+		poptBadOption (ctx, POPT_BADOPTION_NOALIAS), 
+		poptStrerror (c));
 	finish_program = 1;
     }
-
+#endif
     probably_finish_program ();
 
-    /* Check for special invocation names mcedit and mcview,
+    /*
+     * Check for special invocation names mcedit and mcview,
      * if none apply then set the current directory and the other
      * directory from the command line arguments
      */
-    tmp = poptGetArg (optCon);
+    tmp = poptGetArg (ctx);
     base = x_basename (argv[0]);
     if (!STRNCOMP (base, "mce", 3) || !STRCOMP(base, "vi")) {
 	edit_one_file = "";
@@ -2892,13 +2737,13 @@ handle_args (int argc, char *argv [])
     	    char buffer[MC_MAXPATHLEN + 2];
 	    this_dir = strdup (tmp);
 	    mc_get_current_wd (buffer, sizeof (buffer) - 2);
-	    if ((tmp = poptGetArg (optCon)))
+	    if ((tmp = poptGetArg (ctx)))
 	        other_dir = strdup (tmp);
 	}
     }
-    poptFreeContext(optCon);
+
+    poptFreeContext (ctx);
 }
-#endif
 
 /*
  * The compatibility_move_mc_files routine is intended to
@@ -2912,7 +2757,7 @@ handle_args (int argc, char *argv [])
 #    define compatibility_move_mc_files()
 #else
 
-int
+static int
 do_mc_filename_rename (char *mc_dir, char *o_name, char *n_name)
 {
 	char *full_o_name = concat_dir_and_file (home_dir, o_name);
@@ -2925,7 +2770,7 @@ do_mc_filename_rename (char *mc_dir, char *o_name, char *n_name)
 	return move;
 }
 
-void
+static void
 do_compatibility_move (char *mc_dir)
 {
 	struct stat s;
@@ -2954,7 +2799,7 @@ do_compatibility_move (char *mc_dir)
 	show_change_notice = 1;
 }
 
-void
+static void
 compatibility_move_mc_files (void)
 {
 	char *mc_dir = concat_dir_and_file (home_dir, ".mc");
@@ -2976,6 +2821,13 @@ int main (int argc, char *argv [])
     bindtextdomain ("mc", LOCALEDIR);
     textdomain ("mc");
 
+    {
+	    volatile  int i = 1;
+
+	    while (!i)
+		    ;
+
+    }
     /* Initialize list of all user group for timur_clr_mode */
     init_groups ();
     
@@ -2998,7 +2850,9 @@ int main (int argc, char *argv [])
 		view_one_file = "";
 	}
     }
-    gnome_init ("gmc", &mc_argp_parser, argc, argv, 0, NULL);
+
+    handle_args(argc, argv);
+
     session_management_setup (argv [0]);
     probably_finish_program ();
 #endif
@@ -3007,16 +2861,18 @@ int main (int argc, char *argv [])
 	exit (1);
 #endif /* HAVE_X */
 
-    
+
+#ifndef HAVE_X
 #ifdef HAVE_SLANG
     SLtt_Ignore_Beep = 1;
 #endif
-
+#endif
+    
     /* NOTE: This has to be called before slang_init or whatever routine
        calls any define_sequence */
     init_key ();
 
-#ifndef PORT_WANTS_ARGP
+#ifndef HAVE_GNOME
     handle_args (argc, argv);
 #endif
     
@@ -3060,7 +2916,6 @@ int main (int argc, char *argv [])
     
     /* Install the SIGCHLD handler; must be done before init_subshell() */
     init_sigchld ();
-    init_sigfatals ();
     
     /* This variable is used by the subshell */
     home_dir = getenv ("HOME");
