@@ -7,14 +7,7 @@
 #    include "slang.h"
 #endif
 
-enum {
-    KEY_BACKSPACE = 400,
-    KEY_END, KEY_UP, KEY_DOWN, KEY_LEFT, KEY_RIGHT,
-    KEY_HOME, KEY_A1, KEY_C1, KEY_NPAGE, KEY_PPAGE, KEY_IC,
-    KEY_ENTER, KEY_DC, KEY_SCANCEL, KEY_BTAB
-};
-
-#define KEY_F(x) 1000+x
+#include "keys.h"
 
 #define ACS_VLINE SLSMG_VLINE_CHAR
 #define ACS_HLINE SLSMG_HLINE_CHAR
@@ -54,8 +47,11 @@ enum {
 
 #define COLOR_PAIR(x) x
 #define ERR -1
-#define TRUE 1
-#define FALSE 0
+
+#ifndef TRUE
+#    define TRUE 1
+#    define FALSE 0
+#endif
 
 void slang_set_raw_mode (void);
 
@@ -88,7 +84,7 @@ void slang_shell_mode (void);
 void slang_shutdown (void);
 int has_colors (void);
 /* Internal function prototypes */
-void load_terminfo_keys ();
+void load_terminfo_keys (void);
 
 /* FIXME Clean up this; gnome has nothing to do here */
 #ifndef HAVE_GNOME
@@ -136,6 +132,6 @@ void init_pair (int, char *, char *);
 #   define one_hline() SLsmg_draw_object (SLsmg_get_row(), SLsmg_get_column(), slow_terminal ? ' ' : ACS_HLINE) 
 #endif    
 
-void enable_interrupt_key ();
-void disable_interrupt_key ();
+void enable_interrupt_key (void);
+void disable_interrupt_key (void);
 #endif
