@@ -111,19 +111,25 @@ typedef struct {
     int      searching;
     char     search_buffer [256];
    
-    int      has_dir_sizes;	/* Set if directories have sizes = to du -s */
+    void     *port_ui;		/* UI stuff specific to each GUI port */
 
 #ifdef HAVE_GNOME
     /* These are standard GtkWidgets */
 	
     void *xwindow;		/* The toplevel window */
-	
+
     void *table;
+    void *view_table;
+    void *pane;
     void *list;
+    void *tree;
     void *icons;
+    void *notebook;
+    void *scrollbar;
     void *status;
     void *ministatus;
-
+    void *tree_scrolled_window;
+	
     void *filter_w;		/* A WInput* */
     void *current_dir;		/* A WInput* */
     int estimated_total;
@@ -132,7 +138,19 @@ typedef struct {
     void *back_b;
     void *fwd_b;
     void *up_b;
+    /* Used during drag and drop */
+    int maybe_start_drag;
+    int click_x, click_y;
+
+    int dragging;
+
+    /* Used for scrolling nicely during drags */
+    int timer_id;
+    int drag_motion_x;
+    int drag_motion_y;
+    
 #endif
+    void *corbadat;
 } WPanel;
 
 WPanel *panel_new (char *panel_name);
@@ -243,11 +261,13 @@ char *string_inode (file_entry *fe, int len);
 char *string_file_ngid (file_entry *fe, int len);
 char *string_file_nuid (file_entry *fe, int len);
 
+void recalculate_panel_summary (WPanel *panel);
 void file_mark (WPanel *panel, int index, int val);
 void do_file_mark (WPanel *panel, int index, int val);
 int  file_compute_color (int attr, file_entry *fe);
 int  file_entry_color (file_entry *fe);
 void do_file_mark_range (WPanel *panel, int r1, int r2);
+int do_enter_on_file_entry (file_entry *fe);
 int do_enter (WPanel *panel);
 
 /* NOTE: Have to be ifdefed for HAVE_X */
