@@ -59,7 +59,6 @@
 
 #include "x.h"
 
-/* "$Id: screen.c,v 1.33 1998/10/05 19:38:45 norbert Exp $" */
 #define ELEMENTS(arr) ( sizeof(arr) / sizeof((arr)[0]) )
 
 /* If true, show the mini-info on the panel */
@@ -143,7 +142,7 @@ set_colors (WPanel *panel)
 #endif
 
 /* Delete format string, it is a linked list */
-void
+static void
 delete_format (format_e *format)
 {
     format_e *next;
@@ -155,8 +154,9 @@ delete_format (format_e *format)
      }
 }
 
+#ifndef HAVE_X
 /* This code relies on the default justification!!! */
-void
+static void
 add_permission_string (char *dest, int width, file_entry *fe, int attr, int color, int is_octal)
 {
     int i, r, l;
@@ -185,6 +185,7 @@ add_permission_string (char *dest, int width, file_entry *fe, int attr, int colo
 	addch (dest[i]);
     }
 }
+#endif /* HAVE_X */
 
 int
 file_entry_color (file_entry *fe)
@@ -196,7 +197,7 @@ file_entry_color (file_entry *fe)
             if (fe->f.link_to_dir)
                 return (DIRECTORY_COLOR);
             else if (fe->f.stalled_link)
-                return (STALLED_COLOR);
+                return (STALLED_LINK_COLOR);
             else
                 return (LINK_COLOR);
         } else if (S_ISSOCK (fe->buf.st_mode))
@@ -829,47 +830,32 @@ do_select (WPanel *panel, int i)
 void
 Xtry_to_select (WPanel *panel, char *name)
 {
-    int i, best = -1, bestl = -1;
+    int i;
     char *subdir;
-    
+
     if (!name) {
         do_select(panel, 0);
 	return;
     }
 
     /* We only want the last component of the directory */
-    subdir = x_basename(name);
-    
-    if (subdir < name)
-	subdir = name;
-    
+    subdir = x_basename (name);
+
+    subdir = vfs_strip_suffix_from_filename (subdir);
+
     /* Search that subdirectory, if found select it */
     for (i = 0; i < panel->count; i++){
-        char *s = panel->dir.list [i].fname;
-        int l = strlen (s);
-	if (strncmp (subdir, s, l))
-	    continue;
-
-        if (l == strlen(subdir)){
-	    /* Complete match, hilight */
+	if (strcmp (subdir, panel->dir.list [i].fname) == 0) {
 	    do_select (panel, i);
+            free (subdir);
 	    return;
-	}
-        if (bestl > l)
-	    continue;
-        bestl = l;
-	best = i;
-    }
-
-    if (best != -1) {
-      /* Try to select longest inclusive match - good for vfs */
-       do_select (panel, best);
-       return;
+        }
     }
 
     /* Try to select a file near the file that is missing */
     if (panel->selected >= panel->count)
         do_select (panel, panel->count-1);
+    free (subdir);
 }
 
 #ifndef PORT_HAS_PANEL_UPDATE_COLS
@@ -1007,7 +993,6 @@ panel_new (char *panel_name)
     panel->searching        = 0;
     panel->dirs_marked      = 0;
     panel->is_panelized     = 0;
-    panel->has_dir_sizes    = 0;
     panel->format	    = 0;
     panel->status_format    = 0;    
     panel->format_modified  = 1;
@@ -1051,7 +1036,6 @@ panel_new (char *panel_name)
 void
 panel_reload (WPanel *panel)
 {
-    int i;
     struct stat current_stat;
 
     if (fast_reload
@@ -1079,19 +1063,11 @@ panel_reload (WPanel *panel)
     
     panel->count = do_reload_dir (&panel->dir, panel->sort_type, panel->count,
 				  panel->reverse, panel->case_sensitive, panel->filter);
-    panel->marked = 0;
-    panel->dirs_marked = 0;
-    panel->total  = 0;
-    panel->has_dir_sizes = 0;
 
-    for (i = 0; i < panel->count; i++)
-	if (panel->dir.list [i].f.marked){
-	    /* do_file_mark will return immediately if newmark == oldmark.
-	       So we have to first unmark it to get panel's summary information
-	       updated. (Norbert) */
-	    panel->dir.list [i].f.marked = 0;
-	    do_file_mark (panel, i, 1);
-	}
+    if (panel->selected >= panel->count)
+        do_select (panel, panel->count-1);
+
+    recalculate_panel_summary (panel);
 }
 
 #ifndef PORT_HAS_PAINT_FRAME
@@ -1204,7 +1180,7 @@ parse_panel_size (WPanel *panel, char *format, int isstatus)
    
 */
 
-format_e *
+static format_e *
 parse_display_format (WPanel *panel, char *format, char **error, int isstatus, int *res_total_cols)
 {
     format_e *darr, *old, *home = 0;   	/* The formats we return */
@@ -1903,6 +1879,27 @@ move_end (WPanel *panel)
     select_item (panel);
 }
 
+/* Recalculate the panels summary information, used e.g. when marked
+   files might have been removed by an external command */
+void
+recalculate_panel_summary (WPanel *panel)
+{
+    int i;
+
+    panel->marked = 0;
+    panel->dirs_marked = 0;
+    panel->total  = 0;
+
+    for (i = 0; i < panel->count; i++)
+	if (panel->dir.list [i].f.marked){
+	    /* do_file_mark will return immediately if newmark == oldmark.
+	       So we have to first unmark it to get panel's summary information
+	       updated. (Norbert) */
+	    panel->dir.list [i].f.marked = 0;
+	    do_file_mark (panel, i, 1);
+	}
+}
+
 /* This routine marks a file or a directory */
 void
 do_file_mark (WPanel *panel, int idx, int mark)
@@ -1917,17 +1914,15 @@ do_file_mark (WPanel *panel, int idx, int mark)
         if (panel->dir.list [idx].f.marked){
             panel->marked++;
             if (S_ISDIR (panel->dir.list [idx].buf.st_mode)) {
-		if (panel->has_dir_sizes)
+		if (panel->dir.list [idx].f.dir_size_computed)
 		    panel->total += panel->dir.list [idx].buf.st_size;
                 panel->dirs_marked++;
 	    } else 
 		panel->total += panel->dir.list [idx].buf.st_size;
-#ifndef HAVE_XVIEW            
             set_colors (panel);
-#endif
         } else {
             if (S_ISDIR(panel->dir.list [idx].buf.st_mode)) {
-		if (panel->has_dir_sizes)
+		if (panel->dir.list [idx].f.dir_size_computed)
 		    panel->total -= panel->dir.list [idx].buf.st_size;
                 panel->dirs_marked--;
 	    } else
@@ -1954,10 +1949,9 @@ static void
 do_mark_file (WPanel *panel, int do_move)
 {
     int idx = panel->selected;
+
     do_file_mark (panel, idx, selection (panel)->f.marked ? 0 : 1);
-#ifndef HAVE_XVIEW	
     repaint_file (panel, idx, 1, 2*panel->dir.list [idx].f.marked+1, 0);
-#endif        
 
     if (mark_moves_down && do_move)
 	move_down (panel);
@@ -2030,20 +2024,19 @@ start_search (WPanel *panel)
 }
 
 int
-do_enter (WPanel *panel)
+do_enter_on_file_entry (file_entry *fe)
 {
-    if (S_ISDIR (selection (panel)->buf.st_mode)
-	|| link_isdir (selection (panel))){
-	do_cd (selection (panel)->fname, cd_exact);
+    if (S_ISDIR (fe->buf.st_mode) || link_isdir (fe)) {
+	do_cd (fe->fname, cd_exact);
 	return 1;
     } else { 
-	if (is_exe (selection (panel)->buf.st_mode) &&
-	    if_link_is_exe (selection (panel))) {
+	if (is_exe (fe->buf.st_mode) &&
+	    if_link_is_exe (fe)) {
 #ifdef USE_VFS	    
 	    if (vfs_current_is_local ()) 
 #endif	    
 	    {
-	        char *tmp = name_quote (selection (panel)->fname, 0);
+	        char *tmp = name_quote (fe->fname, 0);
 	        char *cmd = copy_strings (".", PATH_SEP_STR, tmp, 0);
 	        if (!confirm_execute || (query_dialog (_(" The Midnight Commander "),
 						       _(" Do you really want to execute? "),
@@ -2053,26 +2046,43 @@ do_enter (WPanel *panel)
 	        free (cmd);
 	    } 
 #ifdef USE_VFS	    	    
-	    else if (vfs_current_is_extfs ()) {
-	        char *tmp = vfs_get_current_dir();
-	        char *tmp2;
+	    else {
+	      /* if (vfs_current_is_extfs ()) - I see no reason why
+                 filesystems other than extfs could not implement same
+                 call...                              -- pavel@ucw.cz*/
+	        char *tmp;
 
-		tmp2 = concat_dir_and_file (tmp, selection (panel)->fname);
-	        extfs_run(tmp2);
-	        free (tmp2);
+		tmp = concat_dir_and_file (vfs_get_current_dir(), fe->fname);
+		if (!mc_setctl (tmp, MCCTL_EXTFS_RUN, NULL))
+		    message (1, _(" Warning "), _(" No action taken "));
+
+	        free (tmp);
 	    }
 #endif /* USE_VFS */	    
 	    return 1;
 	} else {
 	    char *p;
-	    
-	    p = regex_command (selection (panel)->fname, "Open", NULL, 0);
+
+#ifdef HAVE_GNOME
+	    if (gmc_open (fe))
+		    return 1;
+	    else
+		    return 0;
+#else
+	    p = regex_command (fe->fname, "Open", NULL, 0);
+#endif
 	    if (p && (strcmp (p, "Success") == 0))
 		    return 1;
 	    else
 		    return 0;
 	}
     }
+}	
+
+int
+do_enter (WPanel *panel)
+{
+    return do_enter_on_file_entry (selection (panel));
 }
 
 static void
@@ -2277,11 +2287,7 @@ panel_callback (Dlg_head *h, WPanel *panel, int msg, int par)
 	return 1;
 	
     case WIDGET_DRAW:
-#ifndef HAVE_XVIEW
 	paint_panel (panel);
-#else
-	show_dir (panel);	
-#endif
 	break;
 
     case WIDGET_FOCUS:
@@ -2290,7 +2296,7 @@ panel_callback (Dlg_head *h, WPanel *panel, int msg, int par)
 #endif
 	panel->active = 1;
 	if (mc_chdir (panel->cwd) != 0){
-	    message (1, " Error ", " Can't chdir to %s \n %s ",
+	    message (1, _(" Error "), _(" Can't chdir to %s \n %s "),
 		     panel->cwd, unix_error_string (errno));
 	} else
 	    subshell_chdir (panel->cwd);
