@@ -25,14 +25,13 @@
 #include <stdio.h>
 #include "mad.h"
 #include "dir.h"
-#include "file.h"
 #include "global.h"
 #include "util.h"		/* Functions and externs */
 #include "panel.h"
 #include "main.h"
 #include "tree.h"
 #include "profile.h"
-#define WANT_DEFAULTS
+#define WANT_WIDGETS
 #include "setup.h"
 #include "mouse.h"		/* To make view.h happy */
 #include "view.h"		/* For the externs */
@@ -43,6 +42,7 @@
 #include "menu.h"		/* menubar_visible declaration */
 #include "win.h"		/* lookup_key */
 #include "cmd.h"
+#include "file.h"
 #include "x.h"
 
 #ifdef HAVE_GNOME
@@ -66,7 +66,7 @@ extern int ftpfs_use_passive_connections;
 extern int ftpfs_use_unix_list_options;
 #endif
 
-/* "$Id: setup.c,v 1.12 1998/10/11 19:19:06 norbert Exp $" */
+/* "$Id: setup.c,v 1.18 1998/12/21 23:31:06 norbert Exp $" */
 
 #ifdef USE_VFS
 extern int vfs_timeout;
@@ -209,6 +209,7 @@ static struct {
     { "panel_scroll_pages", &panel_scroll_pages },
     { "xtree_mode", &xtree_mode },
     { "num_history_items_recorded", &num_history_items_recorded },
+    { "file_op_compute_totals", &file_op_compute_totals },
 #ifdef SAVE_CHANGES_OUTSIDE_OPTIONS_MENU
     { "dive_into_subdirs", &dive_into_subdirs },
     { "preserve_uidgid", &preserve_uidgid },
@@ -217,9 +218,7 @@ static struct {
     { "tree_navigation_flag", &tree_navigation_flag },
 #endif
 #ifdef USE_VFS    
-    { "tar_gzipped_memlimit", &tar_gzipped_memlimit },
     { "vfs_timeout", &vfs_timeout },
-    { "vfs_use_targz_memlimit", &vfs_use_limit },
 #ifdef USE_NETCODE
     { "ftpfs_directory_timeout", &ftpfs_directory_timeout },
     { "use_netrc", &use_netrc },
@@ -245,18 +244,15 @@ static struct {
     { "editor_syntax_highlighting", &option_syntax_highlighting },
 #endif
 
-#ifdef HAVE_GNOME
-    { "want_transparent_text", &want_transparent_text },
-    { "want_transparent_icons", &want_transparent_icons },
-    { "icons_snap_to_grid", &icons_snap_to_grid },
-#else
+#ifndef HAVE_GNOME
     { "nice_rotating_dash", &nice_rotating_dash },
     { "horizontal_split", &horizontal_split },
 #endif
     { 0, 0 }
 };
 
-void panel_save_setup (WPanel *panel, char *section)
+void
+panel_save_setup (WPanel *panel, char *section)
 {
     char buffer [40];
     int  i;
@@ -292,7 +288,8 @@ void panel_save_setup (WPanel *panel, char *section)
 			       profile_name);
 }
 
-void save_layout (void)
+void
+save_layout (void)
 {
     char *profile;
     int  i;
@@ -309,7 +306,8 @@ void save_layout (void)
     free (profile);
 }
 
-void save_configure (void)
+void
+save_configure (void)
 {
     char *profile;
     int  i;
@@ -323,7 +321,8 @@ void save_configure (void)
     free (profile);
 }
 
-static void panel_save_type (char *section, int type)
+static void
+panel_save_type (char *section, int type)
 {
     int i;
     
@@ -336,7 +335,8 @@ static void panel_save_type (char *section, int type)
 }
 
 #ifndef PORT_HAS_SAVE_PANEL_TYPES
-void save_panel_types ()
+void
+save_panel_types ()
 {
     int type;
 
@@ -351,7 +351,8 @@ void save_panel_types ()
 }
 #endif
 
-void save_setup (void)
+void
+save_setup (void)
 {
     char *profile;
 #ifdef USE_VFS
@@ -388,7 +389,8 @@ void save_setup (void)
     saving_setup = 0;
 }
 
-void panel_load_setup (WPanel *panel, char *section)
+void
+panel_load_setup (WPanel *panel, char *section)
 {
     int i;
     char buffer [40];
@@ -439,7 +441,8 @@ void panel_load_setup (WPanel *panel, char *section)
 
 }
 
-static void load_layout (char *profile_name)
+static void
+load_layout (char *profile_name)
 {
     int i;
     
@@ -449,7 +452,8 @@ static void load_layout (char *profile_name)
 				  *layout [i].opt_addr);
 }
 
-static int load_mode (char *section)
+static int
+load_mode (char *section)
 {
     char buffer [20];
     int  i;
@@ -468,7 +472,8 @@ static int load_mode (char *section)
     return mode;
 }
 
-char *do_load_string (char *s, char *ss, char *def)
+static char *
+do_load_string (char *s, char *ss, char *def)
 {
     char *buffer = xmalloc (128, "dls");
     char *p;
@@ -480,7 +485,8 @@ char *do_load_string (char *s, char *ss, char *def)
     return p;
 }
 
-void load_setup (void)
+void
+load_setup (void)
 {
     static char *buffer;
     char   *profile;
@@ -561,7 +567,8 @@ void load_setup (void)
 
 #ifdef USE_VFS
 #ifdef USE_NETCODE
-char *load_anon_passwd ()
+char *
+load_anon_passwd ()
 {
     char buffer [255];
 
@@ -582,7 +589,8 @@ void done_setup (void)
 /*    directory_history_free (); */
 }
 
-void load_keys_from_section (char *terminal, char *profile_name)
+static void
+load_keys_from_section (char *terminal, char *profile_name)
 {
     char *section_name;
     void *profile_keys;
