@@ -15,7 +15,7 @@ void panel_load_setup ();
 #endif
 void load_key_defs (void);
 void save_panel_types (void);
-char *load_anon_passwd ();
+char *load_anon_passwd (void);
 
 extern char *profile_name;
 
@@ -25,6 +25,7 @@ extern char color_terminal_string [];
 
 extern int startup_left_mode;
 extern int startup_right_mode;
+extern int verbose;
 
 #ifdef OS2_NT
 #    define PROFILE_NAME     "mc.ini"
