@@ -23,7 +23,7 @@
    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 
  */
-/* "$Id: widget.c,v 1.19 1998/05/31 20:28:17 norbert Exp $" */
+/* "$Id: widget.c,v 1.22 1998/12/02 23:44:32 unammx Exp $" */
 
 #include <config.h>
 #include <string.h>
@@ -84,7 +84,7 @@ button_callback (Dlg_head *h, WButton *b, int Msg, int Par)
     switch (Msg){
     case WIDGET_INIT:
 	return x_create_button (h, h->wdata, b);
-#ifndef	HAVE_XVIEW
+
     case WIDGET_HOTKEY:
         if (b->hotkey == Par ||  toupper(b->hotkey) == Par){
 	    button_callback (h, b, WIDGET_KEY, ' '); /* to make action */
@@ -104,18 +104,6 @@ button_callback (Dlg_head *h, WButton *b, int Msg, int Par)
 	}
 	return 1;
 
-#ifdef HAVE_TK
-    case WIDGET_FOCUS:
-    case WIDGET_CURSOR:
-    {
-	char *s = b->action == B_ENTER ? ".button" : "";
-	
-	tk_evalf ("focus %s%s", (char *)(b->widget.wdata)+1, s);
-	/* Do not call default_proc: we did the tk focus command */
-	return 1;
-    }
-#else
-	
     case WIDGET_CURSOR:
 	switch (b->flags) {
 	    case DEFPUSH_BUTTON:
@@ -138,6 +126,7 @@ button_callback (Dlg_head *h, WButton *b, int Msg, int Par)
     case WIDGET_UNFOCUS:
     case WIDGET_FOCUS:
     case WIDGET_DRAW:
+#ifndef HAVE_X
 	if (Msg==WIDGET_UNFOCUS) 
 	    b->selected = 0;
 	else if (Msg==WIDGET_FOCUS) 
@@ -174,13 +163,12 @@ button_callback (Dlg_head *h, WButton *b, int Msg, int Par)
 	    widget_move (&b->widget, 0, b->hotpos+off);
 	    addch ((unsigned char)b->text [b->hotpos]);
         }
+#endif /* HAVE_X */
 	if (Msg == WIDGET_FOCUS)
 	    break;
 	else
 	    return 1;
 	break;
-#endif	
-#endif /* !HAVE_XVIEW */
     }	
     return default_proc (h, Msg, Par);
 }
@@ -240,7 +228,7 @@ button_len (const char *text, unsigned int flags)
  * and shifting data past it to the left results to one unused byte.
  * This does not harm though :)
  */
-void
+static void
 button_scan_hotkey(WButton* b)
 {
     char* cp = strchr (b->text, '&');
@@ -303,7 +291,6 @@ radio_callback (Dlg_head *h, WRadio *r, int Msg, int Par)
     case WIDGET_INIT:
 	return x_create_radio (h, h->wdata, r);
 	
-#ifndef HAVE_XVIEW
     case WIDGET_HOTKEY:
 	{
 	    int i, lp = tolower(Par);
@@ -358,7 +345,6 @@ radio_callback (Dlg_head *h, WRadio *r, int Msg, int Par)
 	    x_radio_focus_item (r);
 	    return 1;
 #endif
-#endif
 	
 #ifndef HAVE_X
     case WIDGET_CURSOR:
@@ -465,7 +451,6 @@ check_callback (Dlg_head *h, WCheck *c, int Msg, int Par)
     case WIDGET_INIT:
 	return x_create_check (h, h->wdata, c);
 
-#ifndef	HAVE_XVIEW
     case WIDGET_HOTKEY:
         if (c->hotkey==Par ||
 	    (c->hotkey>='a' && c->hotkey<='z' && c->hotkey-32==Par)){
@@ -502,7 +487,6 @@ check_callback (Dlg_head *h, WCheck *c, int Msg, int Par)
 	}
 	return 1;
 #endif /* !HAVE_X */
-#endif /* !HAVE_XVIEW */
     }
     return default_proc (h, Msg, Par);
 }
@@ -788,6 +772,7 @@ gauge_new (int y, int x, int shown, int max, int current, char *tkname)
 #define should_show_history_button(in) \
 	    (in->history && in->field_len > HISTORY_BUTTON_WIDTH * 2 + 1 && in->widget.parent)
 
+#ifndef HAVE_X
 static void draw_history_button (WInput * in)
 {
     char c;
@@ -814,7 +799,8 @@ static void draw_history_button (WInput * in)
     addch (c);
 #endif
 }
- 
+#endif
+
 /* }}} history button */
 
 
@@ -825,7 +811,6 @@ static char *kill_buffer = 0;
 void
 update_input (WInput *in, int clear_first)
 {
-#ifndef HAVE_XVIEW
     int has_history = 0;
     int    i, j;
     unsigned char   c;
@@ -877,8 +862,6 @@ update_input (WInput *in, int clear_first)
     if (clear_first)
 	    in->first = 0;
 #endif
-
-#endif
 }
 
 void
@@ -994,7 +977,8 @@ void history_put (char *input_name, Hist *h)
 
 static const char history_title[] = " History ";
 
-int history_callback (Dlg_head * h, int Par, int Msg)
+static int
+history_callback (Dlg_head * h, int Par, int Msg)
 {
 #ifndef HAVE_X
     switch (Msg) {
@@ -1630,7 +1614,6 @@ input_callback (Dlg_head *h, WInput *in, int Msg, int Par)
     case WIDGET_INIT:
 	return x_create_input (h, h->wdata, in);
 
-#ifndef HAVE_XVIEW
     case WIDGET_KEY:
 	if (Par == XCTRL('q')){
 	    int v;
@@ -1656,7 +1639,6 @@ input_callback (Dlg_head *h, WInput *in, int Msg, int Par)
     case WIDGET_DRAW:
 	update_input (in, 0);
 	break;
-#endif /* !HAVE_XVIEW */
 #ifndef HAVE_X
     case WIDGET_CURSOR:
 	widget_move (&in->widget, 0, in->point - in->first_shown);
@@ -1748,6 +1730,13 @@ input_new (int y, int x, int color, int len, char *def_text, char *tkname)
  */
 static int listbox_cdiff (WLEntry *s, WLEntry *e);
 
+#ifdef HAVE_X
+static void
+listbox_draw (WListbox *l, Dlg_head *h, int focused)
+{
+	/* nothing */
+}
+#else
 static void
 listbox_drawscroll (WListbox *l)
 {
@@ -1829,6 +1818,7 @@ listbox_draw (WListbox *l, Dlg_head *h, int focused)
     attrset (normalc);
     listbox_drawscroll (l);
 }
+#endif /* HAVE_X */
 
 /* Returns the number of items between s and e,
    must be on the same linked list */
@@ -2090,7 +2080,6 @@ listbox_callback (Dlg_head *h, WListbox *l, int msg, int par)
     case WIDGET_INIT:
 	return x_create_listbox (h, h->wdata, l);
 	
-#ifndef	HAVE_XVIEW
     case WIDGET_HOTKEY:
 	if ((e = listbox_check_hotkey (l, par)) != NULL){
 	    listbox_select_entry (l, e);
@@ -2125,7 +2114,6 @@ listbox_callback (Dlg_head *h, WListbox *l, int msg, int par)
 	listbox_draw (l, h, msg != WIDGET_UNFOCUS);
 	return 1;
 #endif	
-#endif /* !HAVE_XVIEW */
     }
     return default_proc (h, msg, par);
 }
@@ -2331,7 +2319,7 @@ listbox_get_current (WListbox *l, char **string, char **extra)
 	*extra = l->current->data;
 }
 
-int
+static int
 buttonbar_callback (Dlg_head *h, WButtonBar *bb, int msg, int par)
 {
     int i;
@@ -2343,7 +2331,6 @@ buttonbar_callback (Dlg_head *h, WButtonBar *bb, int msg, int par)
     case WIDGET_FOCUS:
 	return 0;
 
-#ifndef	HAVE_XVIEW
     case WIDGET_HOTKEY:
 	for (i = 0; i < 10; i++){
 	    if (par == KEY_F(i+1) && bb->labels [i].function){
@@ -2372,7 +2359,6 @@ buttonbar_callback (Dlg_head *h, WButtonBar *bb, int msg, int par)
 	attrset (SELECTED_COLOR);
 	return 1;
 #endif
-#endif /* !HAVE_XVIEW */
     }
     return default_proc (h, msg, par);
 }
@@ -2447,15 +2433,6 @@ find_buttonbar (Dlg_head *h, Widget *paneletc)
     for (i = 0, item = h->current; i < h->count; i++, item = item->next){
 	if (item->widget->callback == (callback_fn) buttonbar_callback){
 	    bb = (WButtonBar *) item->widget;
-#ifdef HAVE_XVIEW
-	    /* Jakub: do we really need this routine here?
-	     * Does XView hold more that a buttonbar per Dlg_head?
-	     */
-	    if (x_find_buttonbar_check (bb, paneletc)) {
-	        bb = 0;
-	        continue;
-	    }
-#endif	    
 	    break;
 	}
     }
