@@ -31,6 +31,8 @@
 - use hash table instead of linklist to cache ftpfs directory.
  */
 
+/* Namespace pollution: horrible */
+
 #include <config.h>
 #include <stdio.h>
 #include <errno.h>
@@ -71,13 +73,15 @@
 #	include <sys/time.h>	/* alex: this redefines struct timeval */
 #endif /* SCO_FLAVOR */
 #include <sys/param.h>
+#undef MIN
+#undef MAX
+#include <glib.h>
 
 #ifdef USE_TERMNET
 #include <termnet.h>
 #endif
 
 #include "../src/mem.h"
-#define WANT_PARSE_LS_LGA
 #include "vfs.h"
 #include "tcputil.h"
 #include "../src/util.h"
@@ -88,6 +92,7 @@
 #    define MAXHOSTNAMELEN 64
 #endif
 
+#define ERRNOR(x,y) do { my_errno = x; return y; } while(0)
 #define UPLOAD_ZERO_LENGTH_FILE
 
 static int my_errno;
@@ -100,9 +105,9 @@ int ftpfs_retry_seconds = 30;
 int ftpfs_use_passive_connections = 1;
 
 /* Method used to get directory listings:
-   1: try 'LIST -la <path>', if it fails
-      fall back to CWD <path>; LIST 
-   0: always use CWD <path>; LIST  
+ * 1: try 'LIST -la <path>', if it fails
+ *    fall back to CWD <path>; LIST 
+ * 0: always use CWD <path>; LIST  
  */
 int ftpfs_use_unix_list_options = 1;
 
@@ -118,9 +123,6 @@ int ftpfs_directory_timeout;
 /* Proxy host */
 char *ftpfs_proxy_host = 0;
 
-/* Reget flag */
-int do_reget = 0;
-
 /* wether we have to use proxy by default? */
 int ftpfs_always_use_proxy;
 
@@ -141,33 +143,42 @@ static struct linklist *connections_list;
 #define WANT_STRING 0x02
 static char reply_str [80];
 
-static char *ftpfs_get_current_directory(struct connection *bucket);
-static int __ftpfs_chdir (struct connection *bucket ,char *remote_path);
 static struct direntry *_get_file_entry(struct connection *bucket, 
                 char *file_name, int op, int flags);
-static void free_bucket (void *data);
-static void connection_destructor(void *data);
-static void flush_all_directory(struct connection *bucket);
-static int get_line (int sock, char *buf, int buf_len, char term);
-static char *get_path (struct connection **bucket, char *path);
+
+static char    *ftpfs_get_current_directory (struct connection *bucket);
+static int      ftpfs_chdir_internal        (struct connection *bucket,
+					     char *remote_path);
+static void     free_bucket                 (void *data);
+static void     connection_destructor       (void *data);
+static void     flush_all_directory         (struct connection *bucket);
+static int      get_line                    (int sock, char *buf, int buf_len,
+					     char term);
+static char    *get_path                    (struct connection **bucket,
+					     char *path);
 
 /* Extract the hostname and username from the path */
-/* path is in the form: [user@]hostname:port/remote-dir, e.g.:
+
+/*
+ * path is in the form: [user@]hostname:port/remote-dir, e.g.:
  * ftp://sunsite.unc.edu/pub/linux
  * ftp://miguel@sphinx.nuclecu.unam.mx/c/nc
  * ftp://tsx-11.mit.edu:8192/
  * ftp://joe@foo.edu:11321/private
  * If the user is empty, e.g. ftp://@roxanne/private, then your login name
  * is supplied.
- * */
+ *
+ */
 
-static char *my_get_host_and_username (char *path, char **host, char **user, int *port, char **pass)
+static char *
+my_get_host_and_username (char *path, char **host, char **user, int *port, char **pass)
 {
-    return get_host_and_username (path, host, user, port, 21, 1, pass);
+    return vfs_split_url (path, host, user, port, pass, 21, URL_DEFAULTANON);
 }
 
 /* Returns a reply code, check /usr/include/arpa/ftp.h for possible values */
-static int get_reply (int sock, char *string_buf, int string_len)
+static int
+get_reply (int sock, char *string_buf, int string_len)
 {
     char answer[1024];
     int i;
@@ -210,42 +221,48 @@ static int get_reply (int sock, char *string_buf, int string_len)
     }
 }
 
-static int command (struct connection *bucket, int wait_reply,
-		    char *fmt, ...)
+static int
+command (struct connection *bucket, int wait_reply, char *fmt, ...)
 {
     va_list ap;
-    char buf[2048]; /* FIXME: buffer exceed ?? */
+    char *str, *fmt_str;
     int n, status;
     int sock = qsock (bucket);
     
     va_start (ap, fmt);
-    vsnprintf (buf, 2046, fmt, ap);
+
+    fmt_str = g_strdup_vprintf (fmt, ap);
     va_end (ap);
-    n = strlen(buf);
-    buf[n++] = '\r';
-    buf[n++] = '\n';
-    buf[n] = 0;
+
+    str = copy_strings (fmt_str, "\r\n", NULL);
+    g_free (fmt_str);
 
     if (logfile){
-        if (strncmp (buf, "PASS ", 5) == 0) {
+        if (strncmp (str, "PASS ", 5) == 0){
             char *tmp = "PASS <Password not logged>\r\n";
+	    
             fwrite (tmp, strlen (tmp), 1, logfile);
         } else
-	    fwrite (buf, strlen (buf), 1, logfile);
+	    fwrite (str, strlen (str), 1, logfile);
+
 	fflush (logfile);
     }
+
     got_sigpipe = 0;
-    enable_interrupt_key();
-    status = write(sock, buf, strlen(buf));
+    enable_interrupt_key ();
+    status = write (sock, str, strlen (str));
+    free (str);
+    
     if (status < 0){
 	code = 421;
+
 	if (errno == EPIPE){
 	    got_sigpipe = 1;
 	}
-	disable_interrupt_key();
+	disable_interrupt_key ();
 	return TRANSIENT;
     }
-    disable_interrupt_key();
+    disable_interrupt_key ();
     
     if (wait_reply)
 	return get_reply (sock, (wait_reply & WANT_STRING) ? reply_str : NULL, sizeof (reply_str)-1);
@@ -359,38 +376,17 @@ login_server (struct connection *bucket, char *netrcpass)
 #if defined(HSC_PROXY)
 	if (qproxy(bucket)) {
 	    print_vfs_message("ftpfs: sending proxy login name");
-	    if (command (bucket, 1, "USER %s", proxyname) == CONTINUE) {
-		print_vfs_message("ftpfs: sending proxy user password");
-		if (command (bucket, 1, "PASS %s", proxypass) == COMPLETE)
-		    {
-			print_vfs_message("ftpfs: proxy authentication succeeded");
-			if (command (bucket, 1, "SITE %s", qhost(bucket)+1) ==
-			    COMPLETE) {
-			    print_vfs_message("ftpfs: connected to %s", qhost(bucket)+1);
-			}
-			else {
-			    bucket->failed_on_login = 1;
-			    /* my_errno = E; */
-			    if (proxypass)
-				wipe_password (proxypass);
-    			    wipe_password (pass);
-			    free (proxyname);
-			    free (name);
-			    return 0;
-			}
-		    }
-		else {
-		    bucket->failed_on_login = 1;
-		    /* my_errno = E; */
-		    if (proxypass)
-			wipe_password (proxypass);
-		    wipe_password (pass);
-		    free (proxyname);
-		    free (name);
-		    return 0;
-		}
-	    }
-	    else {
+	    if (command (bucket, 1, "USER %s", proxyname) != CONTINUE)
+		goto proxyfail;
+	    print_vfs_message("ftpfs: sending proxy user password");
+	    if (command (bucket, 1, "PASS %s", proxypass) != COMPLETE)
+		goto proxyfail;
+	    print_vfs_message("ftpfs: proxy authentication succeeded");
+	    if (command (bucket, 1, "SITE %s", qhost(bucket)+1) != COMPLETE)
+		goto proxyfail;
+	    print_vfs_message("ftpfs: connected to %s", qhost(bucket)+1);
+	    if (0) {
+	    proxyfail:
 		bucket->failed_on_login = 1;
 		/* my_errno = E; */
 		if (proxypass)
@@ -398,7 +394,7 @@ login_server (struct connection *bucket, char *netrcpass)
 		wipe_password (pass);
 		free (proxyname);
 		free (name);
-		return 0;
+		ERRNOR (EPERM, 0);
 	    }
 	    if (proxypass)
 		wipe_password (proxypass);
@@ -427,19 +423,14 @@ login_server (struct connection *bucket, char *netrcpass)
 		wipe_password (bucket->password);
 	    bucket->password = 0;
 	    
-	    /* This matches the end of the code below, just to make it
-	     * obvious to the optimizer
-	     */
-	    wipe_password (pass);
-	    free (name);
-	    return 0;
+	    goto login_fail;
 	}
     }
     print_vfs_message ("ftpfs: Login incorrect for user %s ", quser(bucket));
-    my_errno = EPERM;
+login_fail:
     wipe_password (pass);
     free (name);
-    return 0;
+    ERRNOR (EPERM, 0);
 }
 
 #ifdef HAVE_SETSOCKOPT
@@ -571,13 +562,12 @@ ftpfs_get_proxy_host_and_port (char *proxy, char **host, int *port)
     char *user, *pass, *dir;
 
 #if defined(HSC_PROXY)
-#define HSC_DEFAULT_PORT 9875
-    dir = get_host_and_username(proxy, host, &user, port, HSC_DEFAULT_PORT, 1,
-				 &pass);
+#define PORT 9875
 #else
-    dir = get_host_and_username(proxy, host, &user, port, 21, 1,
-				 &pass);
+#define PORT 21
 #endif
+    dir = vfs_split_url(proxy, host, &user, port, &pass, PORT, URL_DEFAULTANON);
+
     free(user);
     if (pass)
 	wipe_password (pass);
@@ -957,7 +947,7 @@ error_return:
 
 static int
 open_data_connection (struct connection *bucket, char *cmd, char *remote, 
-		int isbinary)
+		int isbinary, int reget)
 {
     struct sockaddr_in from;
     int s, j, data, fromlen = sizeof(from);
@@ -966,9 +956,8 @@ open_data_connection (struct connection *bucket, char *cmd, char *remote,
         return -1;
     if (changetype (bucket, isbinary) == -1)
         return -1;
-    if (do_reget > 0){
-	j = command (bucket, WAIT_REPLY, "REST %d", do_reget);
-	do_reget = 0;
+    if (reget > 0){
+	j = command (bucket, WAIT_REPLY, "REST %d", reget);
 	if (j != CONTINUE)
 	    return -1;
     }
@@ -1021,15 +1010,13 @@ my_abort (struct connection *bucket, int dsock)
 }
 
 static void
-resolve_symlink(struct connection *bucket, struct dir *dir)
+resolve_symlink_without_ls_options(struct connection *bucket, struct dir *dir)
 {
     struct linklist *flist;
     struct direntry *fe, *fel;
     char tmp[MC_MAXPATHLEN];
     
-    print_vfs_message("Resolving symlink...");
-
-    dir->symlink_status = FTPFS_RESOLVED_SYMLINKS;
+    dir->symlink_status = FTPFS_RESOLVING_SYMLINKS;
     for (flist = dir->file_list->next; flist != dir->file_list; flist = flist->next) {
         /* flist->data->l_stat is alread initialized with 0 */
         fel = flist->data;
@@ -1080,12 +1067,97 @@ resolve_symlink(struct connection *bucket, struct dir *dir)
 	    }
         }
     }
+    dir->symlink_status = FTPFS_RESOLVED_SYMLINKS;
+}
+
+static void
+resolve_symlink_with_ls_options(struct connection *bucket, struct dir *dir)
+{
+    char  buffer[2048] = "", *filename;
+    int sock;
+    FILE *fp;
+    struct stat s;
+    struct linklist *flist;
+    struct direntry *fe;
+    
+    dir->symlink_status = FTPFS_RESOLVED_SYMLINKS;
+    if (strchr (dir->remote_path, ' ')) {
+        if (ftpfs_chdir_internal (bucket, dir->remote_path) != COMPLETE) {
+            print_vfs_message("ftpfs: CWD failed.");
+	    return;
+        }
+        sock = open_data_connection (bucket, "LIST -lLa", ".", TYPE_ASCII, 0);
+    }
+    else
+        sock = open_data_connection (bucket, "LIST -lLa", 
+                                     dir->remote_path, TYPE_ASCII, 0);
+
+    if (sock == -1) {
+	print_vfs_message("ftpfs: couldn't resolve symlink");
+	return;
+    }
+    
+    fp = fdopen(sock, "r");
+    if (fp == NULL) {
+	close(sock);
+	print_vfs_message("ftpfs: couldn't resolve symlink");
+	return;
+    }
+    enable_interrupt_key();
+    flist = dir->file_list->next;
+    while (1) {
+	do {
+	    if (flist == dir->file_list)
+		goto done;
+	    fe = flist->data;
+	    flist = flist->next;
+	} while (!S_ISLNK(fe->s.st_mode));
+	while (1) {
+	    if (fgets (buffer, sizeof (buffer), fp) == NULL)
+		goto done;
+	    if (logfile){
+		fputs (buffer, logfile);
+	        fflush (logfile);
+	    }
+	    if (vfs_parse_ls_lga (buffer, &s, &filename, NULL)) {
+		int r = strcmp(fe->name, filename);
+		free(filename);
+		if (r == 0) {
+		    fe->l_stat = xmalloc(sizeof(struct stat), 
+					 "resolve_symlink: struct stat");
+		    if (fe->l_stat == NULL)
+			goto done;
+		    *fe->l_stat = s;
+                    (*fe->l_stat).st_ino = bucket->__inode_counter++;
+		    break;
+		}
+		if (r < 0)
+		    break;
+	    }
+	}
+    }
+done:
+    while (fgets(buffer, sizeof(buffer), fp) != NULL);
+    disable_interrupt_key();
+    fclose(fp);
+    get_reply(qsock(bucket), NULL, 0);
+}
+
+static void
+resolve_symlink(struct connection *bucket, struct dir *dir)
+{
+    print_vfs_message("Resolving symlink...");
+
+    if (bucket->strict_rfc959_list_cmd) 
+	resolve_symlink_without_ls_options(bucket, dir);
+    else
+        resolve_symlink_with_ls_options(bucket, dir);
 }
 
 
 #define X "ftp"
 #define X_myname "/#ftp:"
-#define X_vfs_ops ftpfs_vfs_ops
+#define vfs_X_ops vfs_ftpfs_ops
 #define X_fill_names ftpfs_fill_names
 #define X_hint_reread ftpfs_hint_reread
 #define X_flushdir ftpfs_flushdir
@@ -1121,7 +1193,8 @@ retrieve_dir(struct connection *bucket, char *remote_path, int resolve_symlinks)
 	    struct timeval tim;
 
 	    gettimeofday(&tim, NULL);
-	    if ((tim.tv_sec < dcache->timestamp.tv_sec) && !force_expiration) {
+	    if (((tim.tv_sec < dcache->timestamp.tv_sec) && !force_expiration)
+                || dcache->symlink_status == FTPFS_RESOLVING_SYMLINKS) {
                 if (resolve_symlinks && dcache->symlink_status == FTPFS_UNRESOLVED_SYMLINKS)
 	            resolve_symlink(bucket, dcache);
 		return dcache;
@@ -1138,11 +1211,11 @@ retrieve_dir(struct connection *bucket, char *remote_path, int resolve_symlinks)
 
     has_symlinks = 0;
     if (bucket->strict_rfc959_list_cmd)
-        print_vfs_message("ftpfs: Reading FTP directory... (don't use UNIX ls options)");
+        print_vfs_message("ftpfs: Reading FTP directory %s... (don't use UNIX ls options)", remote_path);
     else
-        print_vfs_message("ftpfs: Reading FTP directory...");
+        print_vfs_message("ftpfs: Reading FTP directory %s...", remote_path);
     if (has_spaces || bucket->strict_rfc959_list_cmd) 
-        if (__ftpfs_chdir(bucket, remote_path) != COMPLETE) {
+        if (ftpfs_chdir_internal (bucket, remote_path) != COMPLETE) {
             my_errno = ENOENT;
 	    print_vfs_message("ftpfs: CWD failed.");
 	    return NULL;
@@ -1166,17 +1239,17 @@ retrieve_dir(struct connection *bucket, char *remote_path, int resolve_symlinks)
     dcache->symlink_status = FTPFS_NO_SYMLINKS;
 
     if (bucket->strict_rfc959_list_cmd == 1) 
-        sock = open_data_connection (bucket, "LIST", 0, TYPE_ASCII);
+        sock = open_data_connection (bucket, "LIST", 0, TYPE_ASCII, 0);
     else if (has_spaces)
-        sock = open_data_connection (bucket, "LIST -la", ".", TYPE_ASCII);
+        sock = open_data_connection (bucket, "LIST -la", ".", TYPE_ASCII, 0);
     else {
 	char *path = copy_strings (remote_path, PATH_SEP_STR, ".", (char *) 0);
-	sock = open_data_connection (bucket, "LIST -la", path, TYPE_ASCII);
+	sock = open_data_connection (bucket, "LIST -la", path, TYPE_ASCII, 0);
 	free (path);
     }
 
     if (sock == -1)
-	goto error_3;
+	goto fallback;
 
 #ifdef OLD_READ
 #define close_this_sock(x,y) fclose (x)
@@ -1212,13 +1285,12 @@ retrieve_dir(struct connection *bucket, char *remote_path, int resolve_symlinks)
 	    break;
 	fe = xmalloc(sizeof(struct direntry), "struct direntry");
 	fe->freshly_created = 0;
-	fe->tmp_reget = 0;
 	fe->local_filename = NULL;
 	if (fe == NULL) {
 	    my_errno = ENOMEM;
 	    goto error_1;
 	}
-        if (parse_ls_lga (buffer, &fe->s, &fe->name, &fe->linkname)) {
+        if (vfs_parse_ls_lga (buffer, &fe->s, &fe->name, &fe->linkname)) {
 	    fe->count = 1;
 	    fe->local_filename = fe->remote_filename = NULL;
 	    fe->l_stat = NULL;
@@ -1252,23 +1324,8 @@ retrieve_dir(struct connection *bucket, char *remote_path, int resolve_symlinks)
     }
     close_this_sock(fp, sock);
     disable_interrupt_key();
-    if (get_reply (qsock (bucket), NULL, 0) != COMPLETE) {
-	my_errno = EIO;
-        goto error_3;
-    }
-    if (file_list->next == file_list) {
-        if (bucket->__inode_counter == 0 && !bucket->strict_rfc959_list_cmd) {
-            /* It's our first attempt to get a directory listing from this
-               server (UNIX style LIST command) */
-            bucket->strict_rfc959_list_cmd = 1;
-    	    free(dcache->remote_path);
-            free(dcache);
-            linklist_destroy(file_list, direntry_destructor);
-            return retrieve_dir (bucket, remote_path, resolve_symlinks);
-        }
-	my_errno = EACCES;
-	goto error_3;
-    }
+    if ( (get_reply (qsock (bucket), NULL, 0) != COMPLETE) || (file_list->next == file_list))
+        goto fallback;
     if (!linklist_insert(qdcache(bucket), dcache)) {
 	my_errno = ENOMEM;
         goto error_3;
@@ -1294,6 +1351,23 @@ error_3:
     linklist_destroy(file_list, direntry_destructor);
     print_vfs_message("ftpfs: failed");
     return NULL;
+
+fallback:
+    if (bucket->__inode_counter == 0 && (!bucket->strict_rfc959_list_cmd)) {
+        /* It's our first attempt to get a directory listing from this
+	server (UNIX style LIST command) */
+        bucket->strict_rfc959_list_cmd = 1;
+	free(dcache->remote_path);
+	free(dcache);
+	linklist_destroy(file_list, direntry_destructor);
+	return retrieve_dir (bucket, remote_path, resolve_symlinks);
+    }
+    my_errno = EACCES;
+    free(dcache->remote_path);
+    free(dcache);
+    linklist_destroy(file_list, direntry_destructor);
+    print_vfs_message("ftpfs: failed; nowhere to fallback to");
+    return NULL;
 }
 
 static int
@@ -1312,7 +1386,7 @@ store_file(struct direntry *fe)
     unlink (fe->local_filename);
     if (local_handle == -1) ERRNOR (EIO, 0);
     fstat(local_handle, &s);
-    sock = open_data_connection(fe->bucket, "STOR", fe->remote_filename, TYPE_BINARY);
+    sock = open_data_connection(fe->bucket, "STOR", fe->remote_filename, TYPE_BINARY, 0);
     if (sock < 0) {
 	close(local_handle);
 	return 0;
@@ -1372,12 +1446,13 @@ error_return:
 }
 
 static int 
-linear_start(struct direntry *fe)
+linear_start(struct direntry *fe, int offset)
 {
     fe->local_stat.st_mtime = 0;
-    fe->data_sock = open_data_connection(fe->bucket, "RETR", fe->remote_filename, TYPE_BINARY);
+    fe->data_sock = open_data_connection(fe->bucket, "RETR", fe->remote_filename, TYPE_BINARY, offset);
     if (fe->data_sock == -1)
 	ERRNOR (EACCES, 0);
+    fe->linear_state = LS_LINEAR_OPEN;
     return 1;
 }
 
@@ -1405,6 +1480,7 @@ linear_read (struct direntry *fe, void *buf, int len)
 	    my_errno = EIO;
 	    n=-1;
 	}
+	close (fe->data_sock);
 	fe->data_sock = -1;
     }
     ERRNOR (errno, n);
@@ -1423,8 +1499,14 @@ int ftpfs_ctl (void *data, int ctlop, int arg)
     switch (ctlop) {
         case MCCTL_IS_NOTREADY:
 	    {
-	        int v = select_on_two (fp->fe->data_sock, 0);
+	        int v;
 		
+		if (!fp->fe->linear_state)
+		    vfs_die ("You may not do this");
+		if (fp->fe->linear_state == LS_LINEAR_CLOSED)
+		    return 0;
+
+		v = select_on_two (fp->fe->data_sock, 0);
 		if (((v < 0) && (errno == EINTR)) || v == 0)
 		    return 1;
 		return 0;
@@ -1446,7 +1528,7 @@ send_ftp_command(char *filename, char *cmd, int flags)
 	return -1;
     r = command (bucket, WAIT_REPLY, cmd, remote_path);
     free(remote_path);
-    vfs_add_noncurrent_stamps (&ftpfs_vfs_ops, (vfsid) bucket, NULL);
+    vfs_add_noncurrent_stamps (&vfs_ftpfs_ops, (vfsid) bucket, NULL);
     if (flags & OPT_IGNORE_ERROR)
 	r = COMPLETE;
     if (r != COMPLETE) ERRNOR (EPERM, -1);
@@ -1468,7 +1550,7 @@ ftpfs_init_passwd(void)
 	return;
 
     if ((passwd_info = getpwuid (geteuid ())) == NULL)
-	p = "guest";
+	p = "unknown";
     else
 	p = passwd_info->pw_name;
     gethostname(hostname, sizeof(hostname));
@@ -1488,7 +1570,7 @@ ftpfs_init (vfs *me)
     return 1;
 }
 
-int ftpfs_chmod (vfs *me, char *path, int mode)
+static int ftpfs_chmod (vfs *me, char *path, int mode)
 {
     char buf[40];
     
@@ -1496,7 +1578,7 @@ int ftpfs_chmod (vfs *me, char *path, int mode)
     return send_ftp_command(path, buf, OPT_IGNORE_ERROR | OPT_FLUSH);
 }
 
-int ftpfs_chown (vfs *me, char *path, int owner, int group)
+static int ftpfs_chown (vfs *me, char *path, int owner, int group)
 {
 #if 0
     my_errno = EPERM;
@@ -1525,7 +1607,7 @@ is_same_dir (char *path, struct connection *bucket)
 }
 
 static int
-__ftpfs_chdir (struct connection *bucket ,char *remote_path)
+ftpfs_chdir_internal (struct connection *bucket ,char *remote_path)
 {
     int r;
     
@@ -1615,7 +1697,7 @@ static void my_forget (char *file)
         wipe_password (pass);
 }
 
-vfs ftpfs_vfs_ops = {
+vfs vfs_ftpfs_ops = {
     NULL,	/* This is place of next pointer */
     "File Tranfer Protocol (ftp)",
     F_NET,	/* flags */
@@ -1668,10 +1750,8 @@ vfs ftpfs_vfs_ops = {
     ftpfs_rmdir,
     ftpfs_ctl,
     s_setctl
-#ifdef HAVE_MMAP
-    , NULL,
-    NULL
-#endif
+
+MMAPNULL
 };
 
 #ifdef USE_NETRC
