@@ -6,7 +6,11 @@
  * This defines whole class of filesystems which contain single file
  * inside. It is somehow similar to extfs, except that extfs makes
  * whole virtual trees and we do only single virtual files. 
- */
+ *
+ * If you want to gunzip something, you should open it with #ugz
+ * suffix, DON'T try to gunzip it yourself.
+ *
+ * Namespace: exports vfs_sfs_ops, shell (FIXME) */
 
 #include <config.h>
 #include <errno.h>
@@ -23,7 +27,9 @@
 #include "../src/main.h"
 
 #include "vfs.h"
+#include "local.h"
 
+/* This is needed, or libvfs.so will lack symbol shell. Should look up who requires it */
 char *shell = "/bin/sh";
 
 struct cachedfile {
@@ -87,19 +93,19 @@ static int vfmake( vfs *me, char *name, char *cache )
     }
     free( name );
 
-    if (my_system (EXECUTE_AS_SHELL | EXECUTE_SETUID, shell, pad)) {
+    if (my_system (EXECUTE_AS_SHELL | EXECUTE_SETUID, "/bin/sh", pad)) {
 	return -1;
     }
 
     return 0; /* OK */
 }
 
-#define CUR (*cur)
 static char *redirect( vfs *me, char *name )
 {
     struct cachedfile *cur = head;
     uid_t uid = vfs_uid;
     char *cache, *xname;
+    int handle;
 
     while (cur) {
         if ((!strcmp( name, cur->name )) &&
@@ -107,12 +113,17 @@ static char *redirect( vfs *me, char *name )
 	    (uptodate( cur->name, cur->cache )))
 	  /* FIXME: when not uptodate, we might want to kill cache
 	   * file immediately, not to wait until timeout. */ {
-	    vfs_stamp( &sfs_vfs_ops, cur );
+	    vfs_stamp( &vfs_sfs_ops, cur );
 	    return cur->cache;
 	}
 	cur = cur->next;
     }
     cache = tempnam( NULL, "sfs" );
+    handle = open(cache, O_RDWR | O_CREAT | O_EXCL, 0600);
+    if (handle == -1)
+        return "/SOMEONE_PLAYING_DIRTY_TMP_TRICKS_ON_US";
+    close(handle);
+
     xname = strdup( name );
     if (!vfmake( me, name, cache )) {
         cur = xmalloc( sizeof(struct cachedfile), "SFS cache" );
@@ -122,13 +133,12 @@ static char *redirect( vfs *me, char *name )
 	cur->next = head;
 	head = cur;
 
-	vfs_add_noncurrent_stamps (&sfs_vfs_ops, (vfsid) head, NULL);
+	vfs_add_noncurrent_stamps (&vfs_sfs_ops, (vfsid) head, NULL);
 	vfs_rm_parents (NULL);
 
 	return cache;
     } else {
         free(xname);
-	fprintf( stderr, "vfmake failed\n" );
     }
     return "/I_MUST_NOT_EXIST";
 }
@@ -191,6 +201,7 @@ static int sfs_readlink (vfs *me, char *path, char *buf, int size)
     return readlink (path, buf, size);
 }
 
+#define CUR (*cur)
 static vfsid sfs_getid (vfs *me, char *path, struct vfs_stamping **parent)
 {	/* FIXME: what should I do? */
     vfs *v;
@@ -268,26 +279,6 @@ static void sfs_ungetlocalcopy (vfs *me, char *path, char *local, int has_change
 {
 }
 
-#ifdef HAVE_MMAP
-static caddr_t sfs_mmap (vfs *me, caddr_t addr, size_t len, int prot, int flags, void *data, off_t offset)
-{
-    int fd = * (int *)data;
-
-    return mmap (addr, len, prot, flags, fd, offset);
-}
-
-static int sfs_munmap (vfs *me, caddr_t addr, size_t len, void *data)
-{
-    return munmap (addr, len);
-}
-#endif
-
-extern int local_close (void *data);
-extern int local_read (void *data, char *buffer, int count);
-extern int local_fstat (void *data, struct stat *buf);
-extern int local_errno (vfs *me);
-extern int local_lseek (void *data, off_t offset, int whence);
-
 static int sfs_init (vfs *me)
 {
     FILE *cfg = fopen( LIBDIR "extfs/sfs.ini", "r" );
@@ -369,7 +360,7 @@ static int sfs_which (vfs *me, char *path)
     return -1;
 }
 
-vfs sfs_vfs_ops = {
+vfs vfs_sfs_ops = {
     NULL,	/* This is place of next pointer */
     "Signle file filesystems",
     F_EXEC,	/* flags */
@@ -420,12 +411,12 @@ vfs sfs_vfs_ops = {
     
     NULL,
     NULL,
-    
     NULL,
     NULL
+
 #ifdef HAVE_MMAP
-    ,sfs_mmap,
-    sfs_munmap
+    ,local_mmap,
+    local_munmap
 #endif
 };
 
