@@ -154,82 +154,3 @@ union record {
  * output to the output of 4.2BSD tar, for debugging.
  */
 #define		f_standard		(!f_oldarch)
-
-#ifndef TAR_NAMES
-
-struct inode;
-
-struct entry {
-    int has_changed;
-    long header_offset; /* -1 if not in stored in archive */
-    int header_size;
-    struct entry *next_in_dir;
-    struct entry *dir;
-    long extended_offset; /* -1 if not present */
-    int extended_size;
-    
-    char *name;
-    struct inode *inode;
-};
-
-struct archive;
-
-struct inode {
-    int has_changed;
-    int is_open;
-    nlink_t nlink;
-    struct entry *first_in_subdir; /* only used if linkflag == L_DIR */
-    struct entry *last_in_subdir;
-    long data_offset; 
-    char *local_filename;
-    ino_t inode;        /* This is inode # */
-    dev_t dev;		/* This is an internal identification of the tar archive */
-    struct archive *archive; /* And this is an archive structure */
-    dev_t rdev;
-    int std;		/* 0 if old Unix inode */
-    
-    umode_t mode;
-    uid_t uid;
-    gid_t gid;
-    int size;
-    time_t mtime;
-    char linkflag;
-    char *linkname;
-    time_t atime;
-    time_t ctime;
-};
-
-struct archive {
-    char *name;
-    struct stat tarstat;
-    int is_gzipped;
-    dev_t rdev;
-    ino_t __inode_counter;
-    struct entry *root_entry;
-    struct entry *current_dir;
-    struct archive *next;
-    long current_tar_position;
-    int fd;
-    int fd_usage; /* Zero means fd is invalid, otherwise is number of
-                     pseudofiles that have the archive open */
-    char *tmpname; /* For case of is_gzipped == 2 */
-/* This part is only for gzipped archives: (growable buffers) */
-    union record *block_first;
-    int count_first; /* In records */
-    union record **block_ptr;
-    int count_blocks; /* In blocks */
-    union record *current_record; /* position when reading */
-};
-
-/* This constant determines how many RECORDSIZE blocks are in one growing
-   chunk */
-#define TAR_GROWING_CHUNK_SIZE 64
-
-enum {
-    tar_normal,
-    targz_growing,
-    tar_uncompressed_local
-};
-
-#endif /* ! TAR_NAMES */
-
