@@ -18,6 +18,8 @@
    License along with this program; if not, write to the Free Software
    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.  */
 
+/* Namespace: exports vfs_get_host_and_username */
+
 #ifndef test_get_host_and_username
 #include <config.h>
 #endif
@@ -39,65 +41,7 @@
 #endif
 
 #include <errno.h>
-
-#ifndef test_get_host_and_username
-#include "tcputil.h"
-#include "../src/dialog.h"	/* for message () */
-#include "../src/mem.h"		/* for bcopy */
-#include "../src/util.h"	/* for unix_error_string */
-#include "../src/mad.h"
-
-int open_tcp_link  (char *host, int *port, int *version, char *caller)
-{
-    struct   sockaddr_in server_address;
-    unsigned long inaddr;
-    struct   hostent *hp;
-    int      my_socket;
-
-    if (!*host)
-	return 0;
-    
-    bzero ((char *) &server_address, sizeof (server_address));
-    server_address.sin_family = AF_INET;
-    
-    /*  Try to use the dotted decimal number */
-    if ((inaddr = inet_addr (host)) != -1)
-	bcopy ((char *) &inaddr, (char *) &server_address.sin_addr,
-	       sizeof (inaddr));
-    else {
-	if ((hp = gethostbyname (host)) == NULL){
-	    message_2s (1, caller, " Can't locate hostname: %s ", host);
-	    return 0;
-	}
-	bcopy ((char *) hp->h_addr, (char *) &server_address.sin_addr,
-	       hp->h_length);
-    }
-
-    /* Try to contact a remote portmapper to obtain the listening port */
-    if (*port == 0){
-	*port = get_remote_port (&server_address, version);
-	if (*port < 1)
-	    return 0;
-    } else
-	*version = 1;
-    
-    server_address.sin_port = htons (*port);
-    
-    if ((my_socket = socket (AF_INET, SOCK_STREAM, 0)) < 0){
-	message_2s (1, caller, " Can't create socket: %s ",
-		 unix_error_string(errno));
-	return 0;
-    }
-    if (connect (my_socket, (struct sockaddr *) &server_address,
-	     sizeof (server_address)) < 0){
-	message_2s (1, caller, " Can't connect to server: %s ",
-		 unix_error_string (errno));
-	close (my_socket);
-	return 0;
-    }
-    return my_socket;
-}
-#endif
+#include "vfs.h"
 
 /* Extract the hostname and username from the path */
 /* path is in the form: [user@]hostname:port/remote-dir, e.g.:
@@ -115,27 +59,32 @@ int open_tcp_link  (char *host, int *port, int *version, char *caller)
  * returns a malloced strings with the pathname relative to the host.
  * */
 
-char *get_host_and_username (char *path, char **host, char **user, int *port,
-			     int default_port, int default_is_anon, char **pass)
+char *vfs_split_url (char *path, char **host, char **user, int *port, char **pass,
+				 int default_port, int flags)
 {
     struct passwd *passwd_info;
     char *dir, *colon, *inner_colon, *at, *rest;
     char *retval;
     char *pcopy = strdup (path);
     char *pend   = pcopy + strlen (pcopy);
+    int default_is_anon = flags & URL_DEFAULTANON;
     
     *pass = NULL;
     *port = default_port;
     *user = NULL;
+    retval = NULL;
     
-    /* locate path component */
-    for (dir = pcopy; *dir != '/' && *dir; dir++)
-	;
-    if (*dir){
-	retval = strdup (dir);
-	*dir = 0;
-    } else
-	retval = strdup ("/");
+    dir = pcopy;
+    if (!(flags & URL_NOSLASH)) {
+	/* locate path component */
+	for (; *dir != '/' && *dir; dir++)
+	    ;
+	if (*dir){
+	    retval = strdup (dir);
+	    *dir = 0;
+	} else
+	    retval = strdup ("/");
+    }
     
     /* search for any possible user */
     at    = strchr (pcopy, '@');
@@ -203,102 +152,6 @@ done:
     return retval;
 }
 
-#ifdef old_manual_get_host_and_username
-char *get_host_and_username (char *path, char **host, char **user, int *port,
-			     int default_port, int default_is_anon,
-			     char **pass)
-{
-    struct passwd *passwd_info;
-    char *p, *q;
-
-    *pass = NULL;
-    *port = default_port;
-    for (p = path; ((*p != '/') && (*p != ':')) && *p; p++)
-	;
-
-    q = strchr (path, '@');
-
-    if (q != NULL) {
-        if (q > p) {
-            *user = (char *) xmalloc (p  - path + 1, "get_host_and_username");
-            strncpy (*user, path, p - path);
-            (*user) [p - path] = 0;
-            p++;
-            *pass = (char *) xmalloc (q - p + 1,"get_host_and_username");
-            strncpy (*pass, p, q - p);
-            (*pass) [q - p] = 0;
-            for (p++; ((*p != '/') && (*p != ':')) && *p; p++);
-            q++;
-            *host = (char *) xmalloc (p - q + 1, "get_host_and_username");
-            strncpy (*host, q, p - q);
-            (*host) [p-q] = 0;
-        } else {
-            if (q == path)
-                *user = NULL;
-            else {
-                *user = (char *) xmalloc (q  - path + 1, "get_host_and_username");
-                strncpy (*user, path, q - path);
-                (*user) [q - path] = 0;
-            }
-            q++;
-            *host = (char *) xmalloc (p - q + 1, "get_host_and_username");
-            strncpy (*host, q, p - q);
-            (*host) [p-q] = 0;
-        }
-    } else {
-        *host = (char *) xmalloc (p - path + 1, "get_host_and_username");
-        strncpy (*host, path, p - path);
-        (*host) [p-path] = 0;
-        *user = NULL;
-#ifdef USE_NETRC
-        if (use_netrc)
-            if (lookup_netrc (*host, user, pass) < 0) {
-                if (*user) { free (*user); *user = NULL; }
-                if (*pass) { free (*pass); *pass = NULL; }
-            }
-#endif
-        if (*user == NULL && default_is_anon)
-	    *user = strdup ("anonymous");
-    }
-
-    /* If we got a port spec ... */
-    if (*p == ':'){
-	
-	q = ++p;
-
-	for (;*q != '/' && *q; q++)
-	    ;
-	
-	if (!*q && q == p){
-	    if (!(*user))
-		*user = strdup ("");
-	    /* on return: *host and *user always malloced, *pass malloced
-             * or NULL */
-	    return 0;
-	}
-
-	*port = atoi (p);
-	
-	if (*port <= 0 || *port >= 65536)
-	    *port = 21;
-	p = q;
-    }
-
-    if (!*user){
-	if ((passwd_info = getpwuid (geteuid ())) == NULL)
-	    *user = strdup ("anonymous");
-	else {
-	    *user = strdup (passwd_info->pw_name);
-	}
-	endpwent ();
-    }
-    if (p && *p)
-	return strdup (p);
-     else
-	return strdup ("/");
-}
-#endif
-
 #ifdef test_get_host_and_username
 struct tt {
     char *url;
